"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QMessageBox(QDialog):
    """
    https://doc.qt.io/qt-6/qmessagebox.html

    **Detailed Description**

    A message box displays a primary **text**  to alert the user to a situation,
    an **informative text**  to further explain the alert or to ask the user a
    question, and an optional **detailed text**  to provide even more data if
    the user requests it. A message box can also display an **icon**  and
    **standard buttons**  for accepting a user response.

    Two APIs for using QMessageBox are provided, the property-based API, and the
    static functions. Calling one of the static functions is the simpler
    approach, but it is less flexible than using the property-based API, and the
    result is less informative. Using the property-based API is recommended.

    **The Property-based API**

    To use the property-based API, construct an instance of QMessageBox, set the
    desired properties, and call **exec** () to show the message. The simplest
    configuration is to set only the **message text**  property.

    **QMessageBox**  msgBox;
        msgBox.setText("The document has been
    modified.");
        msgBox.exec();

    The user must click the **OK** button to dismiss the message box. The rest
    of the GUI is blocked until the message box is dismissed.

    ![](images/msgbox1.png)

    A better approach than just alerting the user to an event is to also ask the
    user what to do about it. Store the question in the **informative text**
    property, and set the **standard buttons**  property to the set of buttons
    you want as the set of user responses. The buttons are specified by
    combining values from **StandardButtons**  using the bitwise OR operator.
    The display order for the buttons is platform-dependent. For example, on
    Windows, **Save** is displayed to the left of **Cancel** , whereas on Mac
    OS, the order is reversed.

    Mark one of your standard buttons to be your **default button** .

    **QMessageBox**  msgBox;
        msgBox.setText("The document has been
    modified.");
        msgBox.setInformativeText("Do you want to save your
    changes?");
        msgBox.setStandardButtons(**QMessageBox** ::Save |
    **QMessageBox** ::Discard | **QMessageBox** ::Cancel);
    msgBox.setDefaultButton(**QMessageBox** ::Save);
        int ret =
    msgBox.exec();

    This is the approach recommended in the **macOS Guidelines** . Similar
    guidelines apply for the other platforms, but note the different ways the
    **informative text**  is handled for different platforms.

    ![](images/msgbox2.png)

    The **exec** () slot returns the **StandardButtons**  value of the button
    that was clicked.

    switch (ret) {
          case **QMessageBox** ::Save:
              // Save was
    clicked
              break;
          case **QMessageBox** ::Discard:
              //
    Don't Save was clicked
              break;
          case **QMessageBox** ::Cancel:
    // Cancel was clicked
              break;
          default:
              // should
    never be reached
              break;
        }

    To give the user more information to help him answer the question, set the
    **detailed text**  property. If the **detailed text**  property is set, the
    **Show Details...** button will be shown.

    ![](images/msgbox3.png)

    Clicking the **Show Details...** button displays the detailed text.

    ![](images/msgbox4.png)

    **Rich Text and the Text Format Property**

    The **detailed text**  property is always interpreted as plain text. The
    **main text**  and **informative text**  properties can be either plain text
    or rich text. These strings are interpreted according to the setting of the
    **text format**  property. The default setting is **auto-text** .

    Note that for some plain text strings containing XML meta-characters, the
    auto-text **rich text detection test**  may fail causing your plain text
    string to be interpreted incorrectly as rich text. In these rare cases, use
    **Qt::convertFromPlainText** () to convert your plain text string to a
    visually equivalent rich text string, or set the **text format**  property
    explicitly with **setTextFormat** ().

    **Severity Levels and the Icon and Pixmap Properties**

    QMessageBox supports four predefined message severity levels, or message
    types, which really only differ in the predefined icon they each show.
    Specify one of the four predefined message types by setting the **icon**
    property to one of the **predefined icons** . The following rules are
    guidelines:

    ![](images/qmessagebox-quest.png)

    **Question** For asking a question during
    normal operations.

    ![](images/qmessagebox-info.png)

    **Information**
    For reporting information about normal operations.
    ![](images/qmessagebox-warn.png)

    **Warning** For reporting non-critical
    errors.

    ![](images/qmessagebox-crit.png)

    **Critical** For reporting
    critical errors.

    **Predefined icons**  are not defined by QMessageBox, but provided by the
    style. The default value is **No Icon** . The message boxes are otherwise
    the same for all cases. When using a standard icon, use the one recommended
    in the table, or use the one recommended by the style guidelines for your
    platform. If none of the standard icons is right for your message box, you
    can use a custom icon by setting the **icon pixmap**  property instead of
    setting the **icon**  property.

    In summary, to set an icon, use **either** **setIcon** () for one of the
    standard icons, **or** **setIconPixmap** () for a custom icon.

    **The Static Functions API**

    Building message boxes with the static functions API, although convenient,
    is less flexible than using the property-based API, because the static
    function signatures lack parameters for setting the **informative text**
    and **detailed text**  properties. One work-around for this has been to use
    the `title` parameter as the message box main text and the `text` parameter
    as the message box informative text. Because this has the obvious drawback
    of making a less readable message box, platform guidelines do not recommend
    it. The **Microsoft Windows User Interface Guidelines** recommend using the
    **application name**  as the **window's title** , which means that if you
    have an informative text in addition to your main text, you must concatenate
    it to the `text` parameter.

    Note that the static function signatures have changed with respect to their
    button parameters, which are now used to set the **standard buttons**  and
    the **default button** .

    Static functions are available for creating **information** (), **question**
    (), **warning** (), and **critical** () message boxes.

    int ret = **QMessageBox** ::warning(this, tr("My Application"),
    tr("The document has been modified.\\n"
    "Do you want to save your changes?"),
    **QMessageBox** ::Save | **QMessageBox** ::Discard
    | **QMessageBox** ::Cancel,
    **QMessageBox** ::Save);

    The **Standard Dialogs**  example shows how to use QMessageBox and the other
    built-in Qt dialogs.

    **Advanced Usage**

    If the **standard buttons**  are not flexible enough for your message box,
    you can use the **addButton** () overload that takes a text and a
    **ButtonRole**  to add custom buttons. The **ButtonRole**  is used by
    QMessageBox to determine the ordering of the buttons on screen (which varies
    according to the platform). You can test the value of **clickedButton** ()
    after calling **exec** (). For example,

    **QMessageBox**  msgBox;
        **QPushButton**  *connectButton =
    msgBox.addButton(tr("Connect"), **QMessageBox** ::ActionRole);
    **QPushButton**  *abortButton = msgBox.addButton(**QMessageBox** ::Abort);
    msgBox.exec();

        if (msgBox.clickedButton() == connectButton) {
    // connect
        } else if (msgBox.clickedButton() == abortButton) {
    // abort
        }

    **Default and Escape Keys**

    The default button (i.e., the button activated when **Enter** is pressed)
    can be specified using **setDefaultButton** (). If a default button is not
    specified, QMessageBox tries to find one based on the **button roles**  of
    the buttons used in the message box.

    The escape button (the button activated when **Esc** is pressed) can be
    specified using **setEscapeButton** (). If an escape button is not
    specified, QMessageBox tries to find one using these rules:

    1. If there is only one button, it is the button activated when **Esc** is
    pressed.
      2. If there is a **Cancel**  button, it is the button activated
    when **Esc** is pressed.
      3. If there is exactly one button having either
    **the Reject role**  or the **the No role** , it is the button activated
    when **Esc** is pressed.

    When an escape button can't be determined using these rules, pressing
    **Esc** has no effect.

    **See also** **QDialogButtonBox** , **GUI Design Handbook: Message Box** ,
    **Standard Dialogs Example** , and **Qt Widgets - Application Example** .
    """

    class StandardButton(enum.IntFlag):
        NoButton: QMessageBox = ...
        Ok: QMessageBox = ...
        Save: QMessageBox = ...
        SaveAll: QMessageBox = ...
        Open: QMessageBox = ...
        Yes: QMessageBox = ...
        YesToAll: QMessageBox = ...
        No: QMessageBox = ...
        NoToAll: QMessageBox = ...
        Abort: QMessageBox = ...
        Retry: QMessageBox = ...
        Ignore: QMessageBox = ...
        Close: QMessageBox = ...
        Cancel: QMessageBox = ...
        Discard: QMessageBox = ...
        Help: QMessageBox = ...
        Apply: QMessageBox = ...
        Reset: QMessageBox = ...
        RestoreDefaults: QMessageBox = ...
        FirstButton: QMessageBox = ...
        LastButton: QMessageBox = ...
        YesAll: QMessageBox = ...
        NoAll: QMessageBox = ...
        Default: QMessageBox = ...
        Escape: QMessageBox = ...
        FlagMask: QMessageBox = ...
        ButtonMask: QMessageBox = ...

    class Icon(enum.Enum):
        NoIcon: QMessageBox = ...
        Information: QMessageBox = ...
        Warning: QMessageBox = ...
        Critical: QMessageBox = ...
        Question: QMessageBox = ...

    class ButtonRole(enum.Enum):
        InvalidRole: QMessageBox = ...
        AcceptRole: QMessageBox = ...
        RejectRole: QMessageBox = ...
        DestructiveRole: QMessageBox = ...
        ActionRole: QMessageBox = ...
        HelpRole: QMessageBox = ...
        YesRole: QMessageBox = ...
        NoRole: QMessageBox = ...
        ResetRole: QMessageBox = ...
        ApplyRole: QMessageBox = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#QMessageBox

        **QMessageBox::QMessageBox(QWidget * parent = nullptr)**

        Constructs a message box with no text and no buttons. **parent** is
        passed to the **QDialog**  constructor.

        On macOS, if you want your message box to appear as a **Qt::Sheet**  of
        its **parent** , set the message box's **window modality**  to
        **Qt::WindowModal**  or use **open** (). Otherwise, the message box will
        be a standard dialog.
        """
        ...

    @typing.overload
    def __init__(
        self,
        icon: "QMessageBox.Icon",
        title: str,
        text: str,
        buttons: "QMessageBox.StandardButton" = ...,
        parent: typing.Optional[QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#QMessageBox-1

        **QMessageBox::QMessageBox(QMessageBox::Icon icon , const QString &
        title , const QString & text , QMessageBox::StandardButtons buttons =
        NoButton, QWidget * parent = nullptr, Qt::WindowFlags f = Qt::Dialog |
        Qt::MSWindowsFixedSizeDialogHint)**

        Constructs a message box with the given **icon** , **title** , **text**
        , and standard **buttons**. Standard or custom buttons can be added at
        any time using **addButton** (). The **parent** and **f** arguments are
        passed to the **QDialog**  constructor.

        The message box is an **application modal**  dialog box.

        On macOS, if **parent** is not `nullptr` and you want your message box
        to appear as a **Qt::Sheet**  of that parent, set the message box's
        **window modality**  to **Qt::WindowModal**  (default). Otherwise, the
        message box will be a standard dialog.

        **See also** **setWindowTitle** (), **setText** (), **setIcon** (), and
        **setStandardButtons** ().
        """
        ...

    def checkBox(self) -> QCheckBox:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#checkBox

        **[since 5.2] QCheckBox *QMessageBox::checkBox() const**

        Returns the checkbox shown on the dialog. This is `nullptr` if no
        checkbox is set.

        This function was introduced in Qt 5.2.

        **See also** **setCheckBox** ().
        """
        ...

    def setCheckBox(self, cb: QCheckBox) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#setCheckBox

        **[since 5.2] void QMessageBox::setCheckBox(QCheckBox * cb )**

        Sets the checkbox **cb** on the message dialog. The message box takes
        ownership of the checkbox. The argument **cb** can be `nullptr` to
        remove an existing checkbox from the message box.

        This function was introduced in Qt 5.2.

        **See also** **checkBox** ().
        """
        ...

    def textInteractionFlags(self) -> QtCore.Qt.TextInteractionFlag:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#textInteractionFlags-prop

        **[since 5.1] textInteractionFlags : Qt::TextInteractionFlags**

        Specifies how the label of the message box should interact with user
        input.

        The default value depends on the style.

        This property was introduced in Qt 5.1.

        **Access functions:**

        Qt::TextInteractionFlags **textInteractionFlags** () const
        void
        **setTextInteractionFlags** (Qt::TextInteractionFlags **flags** )

        **See also** **QStyle::SH_MessageBox_TextInteractionFlags** .

        **Member Function Documentation**
        """
        ...

    def setTextInteractionFlags(self, flags: QtCore.Qt.TextInteractionFlag) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#textInteractionFlags-prop

        **[since 5.1] textInteractionFlags : Qt::TextInteractionFlags**

        Specifies how the label of the message box should interact with user
        input.

        The default value depends on the style.

        This property was introduced in Qt 5.1.

        **Access functions:**

        Qt::TextInteractionFlags **textInteractionFlags** () const
        void
        **setTextInteractionFlags** (Qt::TextInteractionFlags **flags** )

        **See also** **QStyle::SH_MessageBox_TextInteractionFlags** .

        **Member Function Documentation**
        """
        ...

    def buttonRole(self, button: QAbstractButton) -> "QMessageBox.ButtonRole":
        """
        https://doc.qt.io/qt-6/qmessagebox.html#buttonRole

        **QMessageBox::ButtonRole QMessageBox::buttonRole(QAbstractButton *
        button ) const**

        Returns the button role for the specified **button**. This function
        returns **InvalidRole**  if **button** is `nullptr` or has not been
        added to the message box.

        **See also** **buttons** () and **addButton** ().
        """
        ...

    def buttons(self) -> typing.List[QAbstractButton]:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#buttons

        **QList<QAbstractButton *> QMessageBox::buttons() const**

        Returns a list of all the buttons that have been added to the message
        box.

        **See also** **buttonRole** (), **addButton** (), and **removeButton**
        ().
        """
        ...

    @typing.overload
    def open(self) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#open

        **void QMessageBox::open(QObject * receiver , const char * member )**

        Opens the dialog and connects its **finished** () or **buttonClicked**
        () signal to the slot specified by **receiver** and **member**. If the
        slot in **member** has a pointer for its first parameter the connection
        is to **buttonClicked** (), otherwise the connection is to **finished**
        ().

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    @typing.overload
    def open(self, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#open

        **void QMessageBox::open(QObject * receiver , const char * member )**

        Opens the dialog and connects its **finished** () or **buttonClicked**
        () signal to the slot specified by **receiver** and **member**. If the
        slot in **member** has a pointer for its first parameter the connection
        is to **buttonClicked** (), otherwise the connection is to **finished**
        ().

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    def setWindowModality(self, windowModality: QtCore.Qt.WindowModality) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#setWindowModality

        **void QMessageBox::setWindowModality(Qt::WindowModality windowModality
        )**

        This function shadows **QWidget::setWindowModality** ().

        Sets the modality of the message box to **windowModality**.

        On macOS, if the modality is set to **Qt::WindowModal**  and the message
        box has a parent, then the message box will be a **Qt::Sheet** ,
        otherwise the message box will be a standard dialog.
        """
        ...

    def setWindowTitle(self, title: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#setWindowTitle

        **void QMessageBox::setWindowTitle(const QString & title )**

        This function shadows **QWidget::setWindowTitle** ().

        Sets the title of the message box to **title**. On macOS, the window
        title is ignored (as required by the macOS Guidelines).
        """
        ...

    def setDetailedText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#detailedText-prop

        **detailedText : QString**

        This property holds the text to be displayed in the details area.

        The text will be interpreted as a plain text.

        By default, this property contains an empty string.

        **Access functions:**

        QString **detailedText** () const
        void **setDetailedText** (const
        QString & **text** )

        **See also** **QMessageBox::text**  and **QMessageBox::informativeText**
        .
        """
        ...

    def detailedText(self) -> str:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#detailedText-prop

        **detailedText : QString**

        This property holds the text to be displayed in the details area.

        The text will be interpreted as a plain text.

        By default, this property contains an empty string.

        **Access functions:**

        QString **detailedText** () const
        void **setDetailedText** (const
        QString & **text** )

        **See also** **QMessageBox::text**  and **QMessageBox::informativeText**
        .
        """
        ...

    def setInformativeText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#informativeText-prop

        **informativeText : QString**

        This property holds the informative text that provides a fuller
        description for the message

        Infromative text can be used to expand upon the **text** () to give more
        information to the user. On the Mac, this text appears in small system
        font below the **text** (). On other platforms, it is simply appended to
        the existing text.

        By default, this property contains an empty string.

        **Access functions:**

        QString **informativeText** () const
        void **setInformativeText**
        (const QString & **text** )

        **See also** **QMessageBox::text**  and **QMessageBox::detailedText** .
        """
        ...

    def informativeText(self) -> str:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#informativeText-prop

        **informativeText : QString**

        This property holds the informative text that provides a fuller
        description for the message

        Infromative text can be used to expand upon the **text** () to give more
        information to the user. On the Mac, this text appears in small system
        font below the **text** (). On other platforms, it is simply appended to
        the existing text.

        By default, this property contains an empty string.

        **Access functions:**

        QString **informativeText** () const
        void **setInformativeText**
        (const QString & **text** )

        **See also** **QMessageBox::text**  and **QMessageBox::detailedText** .
        """
        ...

    def clickedButton(self) -> QAbstractButton:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#clickedButton

        **QAbstractButton *QMessageBox::clickedButton() const**

        Returns the button that was clicked by the user, or `nullptr` if the
        user hit the **Esc** key and no **escape button**  was set.

        If **exec** () hasn't been called yet, returns nullptr.

        Example:

        **QMessageBox**  messageBox(this);
            **QAbstractButton**
        *disconnectButton =
                  messageBox.addButton(tr("Disconnect"),
        **QMessageBox** ::ActionRole);
            ...
            messageBox.exec();
            if
        (messageBox.clickedButton() == disconnectButton) {
                ...
            }

        **See also** **standardButton** () and **button** ().
        """
        ...

    @typing.overload
    def setEscapeButton(self, button: QAbstractButton) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#setEscapeButton

        **void QMessageBox::setEscapeButton(QAbstractButton * button )**

        Sets the button that gets activated when the **Escape** key is pressed
        to **button**.

        **See also** **escapeButton** (), **addButton** (), and
        **clickedButton** ().
        """
        ...

    @typing.overload
    def setEscapeButton(self, button: "QMessageBox.StandardButton") -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#setEscapeButton-1

        **void QMessageBox::setEscapeButton(QMessageBox::StandardButton button
        )**

        Sets the buttons that gets activated when the **Escape** key is pressed
        to **button**.

        **See also** **addButton** () and **clickedButton** ().
        """
        ...

    def escapeButton(self) -> QAbstractButton:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#escapeButton

        **QAbstractButton *QMessageBox::escapeButton() const**

        Returns the button that is activated when escape is pressed.

        By default, **QMessageBox**  attempts to automatically detect an escape
        button as follows:

        1. If there is only one button, it is made the escape button.
          2. If
        there is a **Cancel**  button, it is made the escape button.
          3. On
        macOS only, if there is exactly one button with the role
        **QMessageBox::RejectRole** , it is made the escape button.

        When an escape button could not be automatically detected, pressing
        **Esc** has no effect.

        **See also** **setEscapeButton** () and **addButton** ().
        """
        ...

    @typing.overload
    def setDefaultButton(self, button: QPushButton) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#setDefaultButton

        **void QMessageBox::setDefaultButton(QPushButton * button )**

        Sets the message box's **default button**  to **button**.

        **See also** **defaultButton** (), **addButton** (), and
        **QPushButton::setDefault** ().
        """
        ...

    @typing.overload
    def setDefaultButton(self, button: "QMessageBox.StandardButton") -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#setDefaultButton-1

        **void QMessageBox::setDefaultButton(QMessageBox::StandardButton button
        )**

        Sets the message box's **default button**  to **button**.

        **See also** **addButton** () and **QPushButton::setDefault** ().
        """
        ...

    def defaultButton(self) -> QPushButton:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#defaultButton

        **QPushButton *QMessageBox::defaultButton() const**

        Returns the button that should be the message box's **default button** .
        Returns nullptr if no default button was set.

        **See also** **setDefaultButton** (), **addButton** (), and
        **QPushButton::setDefault** ().
        """
        ...

    def button(self, which: "QMessageBox.StandardButton") -> QAbstractButton:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#button

        **QAbstractButton *QMessageBox::button(QMessageBox::StandardButton which
        ) const**

        Returns a pointer corresponding to the standard button **which** , or
        `nullptr` if the standard button doesn't exist in this message box.

        **See also** **standardButtons**  and **standardButton** ().
        """
        ...

    def standardButton(self, button: QAbstractButton) -> "QMessageBox.StandardButton":
        """
        https://doc.qt.io/qt-6/qmessagebox.html#standardButton

        **QMessageBox::StandardButton
        QMessageBox::standardButton(QAbstractButton * button ) const**

        Returns the standard button enum value corresponding to the given
        **button** , or **NoButton**  if the given **button** isn't a standard
        button.

        **See also** **button** () and **standardButtons** ().
        """
        ...

    def standardButtons(self) -> "QMessageBox.StandardButton":
        """
        https://doc.qt.io/qt-6/qmessagebox.html#standardButtons-prop

        **standardButtons : StandardButtons**

        collection of standard buttons in the message box

        This property controls which standard buttons are used by the message
        box.

        By default, this property contains no standard buttons.

        **Access functions:**

        QMessageBox::StandardButtons **standardButtons** () const
        void
        **setStandardButtons** (QMessageBox::StandardButtons **buttons** )

        **See also** **addButton** ().
        """
        ...

    def setStandardButtons(self, buttons: "QMessageBox.StandardButton") -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#standardButtons-prop

        **standardButtons : StandardButtons**

        collection of standard buttons in the message box

        This property controls which standard buttons are used by the message
        box.

        By default, this property contains no standard buttons.

        **Access functions:**

        QMessageBox::StandardButtons **standardButtons** () const
        void
        **setStandardButtons** (QMessageBox::StandardButtons **buttons** )

        **See also** **addButton** ().
        """
        ...

    def removeButton(self, button: QAbstractButton) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#removeButton

        **void QMessageBox::removeButton(QAbstractButton * button )**

        Removes **button** from the button box without deleting it.

        **See also** **addButton** () and **setStandardButtons** ().
        """
        ...

    @typing.overload
    def addButton(
        self, button: QAbstractButton, role: "QMessageBox.ButtonRole"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#addButton

        **void QMessageBox::addButton(QAbstractButton * button ,
        QMessageBox::ButtonRole role )**

        Adds the given **button** to the message box with the specified
        **role**.

        **See also** **removeButton** (), **button** (), and
        **setStandardButtons** ().
        """
        ...

    @typing.overload
    def addButton(self, text: str, role: "QMessageBox.ButtonRole") -> QPushButton:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#addButton-1

        **QPushButton *QMessageBox::addButton(const QString & text ,
        QMessageBox::ButtonRole role )**

        This is an overloaded function.

        Creates a button with the given **text** , adds it to the message box
        for the specified **role** , and returns it.
        """
        ...

    @typing.overload
    def addButton(self, button: "QMessageBox.StandardButton") -> QPushButton:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#addButton-2

        **QPushButton *QMessageBox::addButton(QMessageBox::StandardButton button
        )**

        This is an overloaded function.

        Adds a standard **button** to the message box if it is valid to do so,
        and returns the push button.

        **See also** **setStandardButtons** ().
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#changeEvent

        **[override virtual protected] void QMessageBox::changeEvent(QEvent * ev
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#keyPressEvent

        **[override virtual protected] void QMessageBox::keyPressEvent(QKeyEvent
        * e )**

        Reimplements: **QDialog::keyPressEvent** (QKeyEvent *e).
        """
        ...

    def closeEvent(self, a0: QtGui.QCloseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#closeEvent

        **[override virtual protected] void QMessageBox::closeEvent(QCloseEvent
        * e )**

        Reimplements: **QDialog::closeEvent** (QCloseEvent *e).
        """
        ...

    def showEvent(self, a0: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#showEvent

        **[override virtual protected] void QMessageBox::showEvent(QShowEvent *
        e )**

        Reimplements: **QDialog::showEvent** (QShowEvent *event).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#resizeEvent

        **[override virtual protected] void
        QMessageBox::resizeEvent(QResizeEvent * event )**

        Reimplements: **QDialog::resizeEvent** (QResizeEvent *).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#event

        **[override virtual protected] bool QMessageBox::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    @staticmethod
    def standardIcon(icon: "QMessageBox.Icon") -> QtGui.QPixmap:
        ...

    @staticmethod
    def aboutQt(parent: QWidget, title: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#aboutQt

        **[static] void QMessageBox::aboutQt(QWidget * parent , const QString &
        title = QString())**

        Displays a simple message box about Qt, with the given **title** and
        centered over **parent** (if **parent** is not `nullptr`). The message
        includes the version number of Qt being used by the application.

        This is useful for inclusion in the **Help** menu of an application, as
        shown in the **Menus**  example.

        **QApplication**  provides this functionality as a slot.

        On macOS, the about box is popped up as a modeless window; on other
        platforms, it is currently application modal.

        **See also** **QApplication::aboutQt** ().
        """
        ...

    @staticmethod
    def about(parent: QWidget, caption: str, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#about

        **[static] void QMessageBox::about(QWidget * parent , const QString &
        title , const QString & text )**

        Displays a simple about box with title **title** and text **text**. The
        about box's parent is **parent**.

        about() looks for a suitable icon in four locations:

        1. It prefers **parent->icon** () if that exists.
          2. If not, it tries
        the top-level widget containing **parent**.
          3. If that fails, it tries
        the **active window.**
          4. As a last resort it uses the Information
        icon.

        The about box has a single button labelled "OK". On macOS, the about box
        is popped up as a modeless window; on other platforms, it is currently
        application modal.

        **See also** **QWidget::windowIcon** () and
        **QApplication::activeWindow** ().
        """
        ...

    @staticmethod
    def critical(
        parent: QWidget,
        title: str,
        text: str,
        buttons: "QMessageBox.StandardButton" = ...,
        defaultButton: "QMessageBox.StandardButton" = ...,
    ) -> "QMessageBox.StandardButton":
        """
        https://doc.qt.io/qt-6/qmessagebox.html#critical

        **[static] QMessageBox::StandardButton QMessageBox::critical(QWidget *
        parent , const QString & title , const QString & text ,
        QMessageBox::StandardButtons buttons = Ok, QMessageBox::StandardButton
        defaultButton = NoButton)**

        Opens a critical message box with the given **title** and **text** in
        front of the specified **parent** widget.

        The standard **buttons** are added to the message box. **defaultButton**
        specifies the button used when **Enter** is pressed. **defaultButton**
        must refer to a button that was given in **buttons**. If
        **defaultButton** is **QMessageBox::NoButton** , **QMessageBox**
        chooses a suitable default automatically.

        Returns the identity of the standard button that was clicked. If **Esc**
        was pressed instead, the **escape button**  is returned.

        The message box is an **application modal**  dialog box.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QMessageBox**  constructors.

        **See also** **question** (), **warning** (), and **information** ().
        """
        ...

    @staticmethod
    def warning(
        parent: QWidget,
        title: str,
        text: str,
        buttons: "QMessageBox.StandardButton" = ...,
        defaultButton: "QMessageBox.StandardButton" = ...,
    ) -> "QMessageBox.StandardButton":
        """
        https://doc.qt.io/qt-6/qmessagebox.html#warning

        **[static] QMessageBox::StandardButton QMessageBox::warning(QWidget *
        parent , const QString & title , const QString & text ,
        QMessageBox::StandardButtons buttons = Ok, QMessageBox::StandardButton
        defaultButton = NoButton)**

        Opens a warning message box with the given **title** and **text** in
        front of the specified **parent** widget.

        The standard **buttons** are added to the message box. **defaultButton**
        specifies the button used when **Enter** is pressed. **defaultButton**
        must refer to a button that was given in **buttons**. If
        **defaultButton** is **QMessageBox::NoButton** , **QMessageBox**
        chooses a suitable default automatically.

        Returns the identity of the standard button that was clicked. If **Esc**
        was pressed instead, the **escape button**  is returned.

        The message box is an **application modal**  dialog box.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QMessageBox**  constructors.

        **See also** **question** (), **information** (), and **critical** ().
        """
        ...

    @staticmethod
    def question(
        parent: QWidget,
        title: str,
        text: str,
        buttons: "QMessageBox.StandardButton" = ...,
        defaultButton: "QMessageBox.StandardButton" = ...,
    ) -> "QMessageBox.StandardButton":
        """
        https://doc.qt.io/qt-6/qmessagebox.html#question

        **[static] QMessageBox::StandardButton QMessageBox::question(QWidget *
        parent , const QString & title , const QString & text ,
        QMessageBox::StandardButtons buttons = StandardButtons(Yes | No),
        QMessageBox::StandardButton defaultButton = NoButton)**

        Opens a question message box with the given **title** and **text** in
        front of the specified **parent** widget.

        The standard **buttons** are added to the message box. **defaultButton**
        specifies the button used when **Enter** is pressed. **defaultButton**
        must refer to a button that was given in **buttons**. If
        **defaultButton** is **QMessageBox::NoButton** , **QMessageBox**
        chooses a suitable default automatically.

        Returns the identity of the standard button that was clicked. If **Esc**
        was pressed instead, the **escape button**  is returned.

        The message box is an **application modal**  dialog box.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QMessageBox**  constructors.

        **See also** **information** (), **warning** (), and **critical** ().
        """
        ...

    @staticmethod
    def information(
        parent: QWidget,
        title: str,
        text: str,
        buttons: "QMessageBox.StandardButton" = ...,
        defaultButton: "QMessageBox.StandardButton" = ...,
    ) -> "QMessageBox.StandardButton":
        """
        https://doc.qt.io/qt-6/qmessagebox.html#information

        **[static] QMessageBox::StandardButton QMessageBox::information(QWidget
        * parent , const QString & title , const QString & text ,
        QMessageBox::StandardButtons buttons = Ok, QMessageBox::StandardButton
        defaultButton = NoButton)**

        Opens an information message box with the given **title** and **text**
        in front of the specified **parent** widget.

        The standard **buttons** are added to the message box. **defaultButton**
        specifies the button used when **Enter** is pressed. **defaultButton**
        must refer to a button that was given in **buttons**. If
        **defaultButton** is **QMessageBox::NoButton** , **QMessageBox**
        chooses a suitable default automatically.

        Returns the identity of the standard button that was clicked. If **Esc**
        was pressed instead, the **escape button**  is returned.

        The message box is an **application modal**  dialog box.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QMessageBox**  constructors.

        **See also** **question** (), **warning** (), and **critical** ().
        """
        ...

    def setTextFormat(self, a0: QtCore.Qt.TextFormat) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#textFormat-prop

        **textFormat : Qt::TextFormat**

        This property holds the format of the text displayed by the message box

        The current text format used by the message box. See the
        **Qt::TextFormat**  enum for an explanation of the possible options.

        The default format is **Qt::AutoText** .

        **Access functions:**

        Qt::TextFormat **textFormat** () const
        void **setTextFormat**
        (Qt::TextFormat **format** )

        **See also** **setText** ().
        """
        ...

    def textFormat(self) -> QtCore.Qt.TextFormat:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#textFormat-prop

        **textFormat : Qt::TextFormat**

        This property holds the format of the text displayed by the message box

        The current text format used by the message box. See the
        **Qt::TextFormat**  enum for an explanation of the possible options.

        The default format is **Qt::AutoText** .

        **Access functions:**

        Qt::TextFormat **textFormat** () const
        void **setTextFormat**
        (Qt::TextFormat **format** )

        **See also** **setText** ().
        """
        ...

    def setIconPixmap(self, a0: QtGui.QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#iconPixmap-prop

        **iconPixmap : QPixmap**

        This property holds the current icon

        The icon currently used by the message box. Note that it's often hard to
        draw one pixmap that looks appropriate in all GUI styles; you may want
        to supply a different pixmap for each platform.

        By default, this property is undefined.

        **Access functions:**

        QPixmap **iconPixmap** () const
        void **setIconPixmap** (const QPixmap
        & **pixmap** )

        **See also** **icon** .
        """
        ...

    def iconPixmap(self) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#iconPixmap-prop

        **iconPixmap : QPixmap**

        This property holds the current icon

        The icon currently used by the message box. Note that it's often hard to
        draw one pixmap that looks appropriate in all GUI styles; you may want
        to supply a different pixmap for each platform.

        By default, this property is undefined.

        **Access functions:**

        QPixmap **iconPixmap** () const
        void **setIconPixmap** (const QPixmap
        & **pixmap** )

        **See also** **icon** .
        """
        ...

    def setIcon(self, a0: "QMessageBox.Icon") -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#icon-prop

        **icon : Icon**

        This property holds the message box's icon

        The icon of the message box can be specified with one of the values:

        * **QMessageBox::NoIcon**
          * **QMessageBox::Question**
          *
        **QMessageBox::Information**
          * **QMessageBox::Warning**
          *
        **QMessageBox::Critical**

        The default is **QMessageBox::NoIcon** .

        The pixmap used to display the actual icon depends on the current **GUI
        style** . You can also set a custom pixmap for the icon by setting the
        **icon pixmap**  property.

        **Access functions:**

        QMessageBox::Icon **icon** () const
        void **setIcon**
        (QMessageBox::Icon)

        **See also** **iconPixmap** .
        """
        ...

    def icon(self) -> "QMessageBox.Icon":
        """
        https://doc.qt.io/qt-6/qmessagebox.html#icon-prop

        **icon : Icon**

        This property holds the message box's icon

        The icon of the message box can be specified with one of the values:

        * **QMessageBox::NoIcon**
          * **QMessageBox::Question**
          *
        **QMessageBox::Information**
          * **QMessageBox::Warning**
          *
        **QMessageBox::Critical**

        The default is **QMessageBox::NoIcon** .

        The pixmap used to display the actual icon depends on the current **GUI
        style** . You can also set a custom pixmap for the icon by setting the
        **icon pixmap**  property.

        **Access functions:**

        QMessageBox::Icon **icon** () const
        void **setIcon**
        (QMessageBox::Icon)

        **See also** **iconPixmap** .
        """
        ...

    def setText(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#text-prop

        **text : QString**

        This property holds the message box text to be displayed.

        The text will be interpreted either as a plain text or as rich text,
        depending on the text format setting (**QMessageBox::textFormat** ). The
        default setting is **Qt::AutoText** , i.e., the message box will try to
        auto-detect the format of the text.

        The default value of this property is an empty string.

        **Access functions:**

        QString **text** () const
        void **setText** (const QString & **text** )

        **See also** **textFormat** , **QMessageBox::informativeText** , and
        **QMessageBox::detailedText** .
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#text-prop

        **text : QString**

        This property holds the message box text to be displayed.

        The text will be interpreted either as a plain text or as rich text,
        depending on the text format setting (**QMessageBox::textFormat** ). The
        default setting is **Qt::AutoText** , i.e., the message box will try to
        auto-detect the format of the text.

        The default value of this property is an empty string.

        **Access functions:**

        QString **text** () const
        void **setText** (const QString & **text** )

        **See also** **textFormat** , **QMessageBox::informativeText** , and
        **QMessageBox::detailedText** .
        """
        ...

    @property
    def buttonClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmessagebox.html#buttonClicked

        **[signal] void QMessageBox::buttonClicked(QAbstractButton * button )**

        This signal is emitted whenever a button is clicked inside the
        **QMessageBox** . The button that was clicked in returned in **button**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNfc import *


class QNdefMessage(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qndefmessage.html

    **Detailed Description**

    A QNdefMessage is a collection of 0 or more QNdefRecords. QNdefMessage
    inherits from **QList** <**QNdefRecord** > and therefore the standard
    **QList**  functions can be used to manipulate the NDEF records in the
    message.

    NDEF messages can be parsed from a byte array conforming to the NFC Data
    Exchange Format technical specification by using the **fromByteArray** ()
    static function. Conversely QNdefMessages can be converted into a byte array
    with the **toByteArray** () function.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qndefmessage.html#QNdefMessage

        **QNdefMessage::QNdefMessage()**

        Constructs a new empty NDEF message.
        """
        ...

    @typing.overload
    def __init__(self, record: "QNdefRecord") -> None:
        """
        https://doc.qt.io/qt-6/qndefmessage.html#QNdefMessage-1

        **QNdefMessage::QNdefMessage(const QNdefRecord & record )**

        Constructs a new NDEF message containing a single record **record**.
        """
        ...

    @typing.overload
    def __init__(self, message: "QNdefMessage") -> None:
        """
        https://doc.qt.io/qt-6/qndefmessage.html#QNdefMessage-2

        **QNdefMessage::QNdefMessage(const QNdefMessage & message )**

        Constructs a new NDEF message that is a copy of **message**.
        """
        ...

    @typing.overload
    def __init__(self, records: typing.Iterable["QNdefRecord"]) -> None:
        """
        https://doc.qt.io/qt-6/qndefmessage.html#QNdefMessage-3

        **QNdefMessage::QNdefMessage(const QList<QNdefRecord> & records )**

        Constructs a new NDEF message that contains all of the records in
        **records**.
        """
        ...

    @staticmethod
    def fromByteArray(message: QtCore.QByteArray) -> "QNdefMessage":
        """
        https://doc.qt.io/qt-6/qndefmessage.html#fromByteArray

        **[static] QNdefMessage QNdefMessage::fromByteArray(const QByteArray &
        message )**

        Returns an NDEF message parsed from the contents of **message**.

        The **message** parameter is interpreted as the raw message format
        defined in the NFC Data Exchange Format technical specification.

        If a parse error occurs an empty NDEF message is returned.
        """
        ...

    def __delitem__(self, i: int) -> None:
        ...

    def __setitem__(self, i: int, value: "QNdefRecord") -> None:
        ...

    def __getitem__(self, i: int) -> "QNdefRecord":
        ...

    def __len__(self) -> int:
        ...

    def toByteArray(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qndefmessage.html#toByteArray

        **QByteArray QNdefMessage::toByteArray() const**

        Returns the NDEF message as a byte array.

        The return value of this function conforms to the format defined in the
        NFC Data Exchange Format technical specification.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QGyroscopeReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qgyroscopereading.html

    **Detailed Description**

    **QGyroscopeReading Units**

    The reading contains 3 values, measured in degrees per second that define
    the movement of the device around the x, y and z axes. Unlike
    **QRotationReading** , the values represent the current angular velocity
    rather than a fixed rotation. The measurements are in degrees per second.

    ![](images/sensors-coordinates3.jpg)
    """

    def setZ(self, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qgyroscopereading.html#setZ

        **void QGyroscopeReading::setZ(qreal z )**

        Sets the angular velocity around the z axis to **z**.

        **See also** **z** ().
        """
        ...

    def z(self) -> float:
        """
        https://doc.qt.io/qt-6/qgyroscopereading.html#z-prop

        **[read-only] z : const qreal**

        This property holds the angular velocity around the z axis.

        Measured as degrees per second.

        **Access functions:**

        qreal **z** () const

        **See also** **QGyroscopeReading Units** .

        **Member Function Documentation**
        """
        ...

    def setY(self, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qgyroscopereading.html#setY

        **void QGyroscopeReading::setY(qreal y )**

        Sets the angular velocity around the y axis to **y**.

        **See also** **y** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qgyroscopereading.html#y-prop

        **[read-only] y : const qreal**

        This property holds the angular velocity around the y axis.

        Measured as degrees per second.

        **Access functions:**

        qreal **y** () const

        **See also** **QGyroscopeReading Units** .
        """
        ...

    def setX(self, x: float) -> None:
        """
        https://doc.qt.io/qt-6/qgyroscopereading.html#setX

        **void QGyroscopeReading::setX(qreal x )**

        Sets the angular velocity around the x axis to **x**.

        **See also** **x** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qgyroscopereading.html#x-prop

        **[read-only] x : const qreal**

        This property holds the angular velocity around the x axis.

        Measured as degrees per second.

        **Access functions:**

        qreal **x** () const

        **See also** **QGyroscopeReading Units** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QGraphicsEffect(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qgraphicseffect.html

    **Detailed Description**

    Effects alter the appearance of elements by hooking into the rendering
    pipeline and operating between the source (e.g., a **QGraphicsPixmapItem** )
    and the destination device (e.g., **QGraphicsView** 's viewport). Effects
    can be disabled by calling **setEnabled** (false). If effects are disabled,
    the source is rendered directly.

    To add a visual effect to a **QGraphicsItem** , for example, you can use one
    of the standard effects, or alternately, create your own effect by creating
    a subclass of QGraphicsEffect. The effect can then be installed on the item
    using **QGraphicsItem::setGraphicsEffect** ().

    Qt provides the following standard effects:

    * **QGraphicsBlurEffect**  \\- blurs the item by a given radius
      *
    **QGraphicsDropShadowEffect**  \\- renders a dropshadow behind the item
      *
    **QGraphicsColorizeEffect**  \\- renders the item in shades of any given
    color
      * **QGraphicsOpacityEffect**  \\- renders the item with an opacity

    ![](images/graphicseffect-plain.png)

    ![](images/graphicseffect-
    blur.png)

    ![](images/graphicseffect-colorize.png)
    ![](images/graphicseffect-opacity.png)

    ![](images/graphicseffect-drop-
    shadow.png)

    ![](images/graphicseffect-widget.png)

    For more information on how to use each effect, refer to the specific
    effect's documentation.

    To create your own custom effect, create a subclass of QGraphicsEffect (or
    any other existing effects) and reimplement the virtual function **draw**
    (). This function is called whenever the effect needs to redraw. The
    **draw** () function takes the painter with which to draw as an argument.
    For more information, refer to the documentation for **draw** (). In the
    **draw** () function you can call **sourcePixmap** () to get a pixmap of the
    graphics effect source which you can then process.

    If your effect changes, use **update** () to request for a redraw. If your
    custom effect changes the bounding rectangle of the source, e.g., a radial
    glow effect may need to apply an extra margin, you can reimplement the
    virtual **boundingRectFor** () function, and call **updateBoundingRect** ()
    to notify the framework whenever this rectangle changes. The virtual
    **sourceChanged** () function is called to notify the effects that the
    source has changed in some way - e.g., if the source is a
    **QGraphicsRectItem**  and its rectangle parameters have changed.

    **See also** **QGraphicsItem::setGraphicsEffect** () and
    **QWidget::setGraphicsEffect** ().
    """

    class PixmapPadMode(enum.Enum):
        NoPad: QGraphicsEffect = ...
        PadToTransparentBorder: QGraphicsEffect = ...
        PadToEffectiveBoundingRect: QGraphicsEffect = ...

    class ChangeFlag(enum.Flag):
        SourceAttached: QGraphicsEffect = ...
        SourceDetached: QGraphicsEffect = ...
        SourceBoundingRectChanged: QGraphicsEffect = ...
        SourceInvalidated: QGraphicsEffect = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#QGraphicsEffect

        **QGraphicsEffect::QGraphicsEffect(QObject * parent = nullptr)**

        Constructs a new QGraphicsEffect instance having the specified
        **parent**.
        """
        ...

    def sourcePixmap(
        self,
        system: QtCore.Qt.CoordinateSystem = ...,
        mode: "QGraphicsEffect.PixmapPadMode" = ...,
    ) -> typing.Tuple[QtGui.QPixmap, QtCore.QPoint]:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#sourcePixmap

        **[protected] QPixmap QGraphicsEffect::sourcePixmap(Qt::CoordinateSystem
        system = Qt::LogicalCoordinates, QPoint * offset = nullptr,
        QGraphicsEffect::PixmapPadMode mode = PadToEffectiveBoundingRect)
        const**

        Returns a pixmap with the source painted into it.

        The **system** specifies which coordinate system to be used for the
        source. The optional **offset** parameter returns the offset where the
        pixmap should be painted at using the current painter. For control on
        how the pixmap is padded use the **mode** parameter.

        The returned pixmap is clipped to the current painter's device rectangle
        when **system** is **Qt::DeviceCoordinates** .

        Calling this function with **Qt::DeviceCoordinates**  outside of
        **QGraphicsEffect::draw** () will give undefined results, as there is no
        device context available.

        **See also** **draw** () and **boundingRect** ().
        """
        ...

    def drawSource(self, painter: QtGui.QPainter) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#drawSource

        **[protected] void QGraphicsEffect::drawSource(QPainter * painter )**

        Draws the source directly using the given **painter**.

        This function should only be called from **QGraphicsEffect::draw** ().

        For example:

        MyGraphicsOpacityEffect::draw(**QPainter**  *painter)
            {
                //
        Fully opaque; draw directly without going through a pixmap.
                if
        (**qFuzzyCompare** (m_opacity, 1)) {
                    drawSource(painter);
        return;
                }
                ...
            }

        **See also** **QGraphicsEffect::draw** ().
        """
        ...

    def sourceBoundingRect(
        self, system: QtCore.Qt.CoordinateSystem = ...
    ) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#sourceBoundingRect

        **[protected] QRectF
        QGraphicsEffect::sourceBoundingRect(Qt::CoordinateSystem system =
        Qt::LogicalCoordinates) const**

        Returns the bounding rectangle of the source mapped to the given
        **system**.

        Calling this function with **Qt::DeviceCoordinates**  outside of
        **QGraphicsEffect::draw** () will give undefined results, as there is no
        device context available.

        **See also** **draw** ().
        """
        ...

    def sourceIsPixmap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#sourceIsPixmap

        **[protected] bool QGraphicsEffect::sourceIsPixmap() const**

        Returns `true` if the source effectively is a pixmap, e.g., a
        **QGraphicsPixmapItem** .

        This function is useful for optimization purposes. For instance, there's
        no point in drawing the source in device coordinates to avoid pixmap
        scaling if this function returns `true` \\- the source pixmap will be
        scaled anyways.
        """
        ...

    def updateBoundingRect(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#updateBoundingRect

        **[protected] void QGraphicsEffect::updateBoundingRect()**

        This function notifies the effect framework when the effect's bounding
        rectangle has changed. As a custom effect author, you must call this
        function whenever you change any parameters that will cause the virtual
        **boundingRectFor** () function to return a different value.

        This function will call **update** () if this is necessary.

        **See also** **boundingRectFor** (), **boundingRect** (), and
        **sourceBoundingRect** ().
        """
        ...

    def sourceChanged(self, flags: "QGraphicsEffect.ChangeFlag") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#sourceChanged

        **[virtual protected] void
        QGraphicsEffect::sourceChanged(QGraphicsEffect::ChangeFlags flags )**

        This virtual function is called by **QGraphicsEffect**  to notify the
        effect that the source has changed. If the effect applies any cache,
        then this cache must be purged in order to reflect the new appearance of
        the source.

        The **flags** describes what has changed.
        """
        ...

    def draw(self, painter: QtGui.QPainter) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#draw

        **[pure virtual protected] void QGraphicsEffect::draw(QPainter * painter
        )**

        This pure virtual function draws the effect and is called whenever the
        source needs to be drawn.

        Reimplement this function in a **QGraphicsEffect**  subclass to provide
        the effect's drawing implementation, using **painter**.

        For example:

        MyGraphicsEffect::draw(**QPainter**  *painter)
            {
                ...
        **QPoint**  offset;
                if (sourceIsPixmap()) {
                    // No
        point in drawing in device coordinates (pixmap will be scaled anyways).
        const **QPixmap**  pixmap = sourcePixmap(Qt::LogicalCoordinates,
        &offset);
                    ...
                    painter->drawPixmap(offset,
        pixmap);
                } else {
                    // Draw pixmap in device
        coordinates to avoid pixmap scaling;
                    const **QPixmap**
        pixmap = sourcePixmap(Qt::DeviceCoordinates, &offset);
        painter->setWorldTransform(**QTransform** ());
                    ...
        painter->drawPixmap(offset, pixmap);
                }
                ...
            }

        This function should not be called explicitly by the user, since it is
        meant for reimplementation purposes only.
        """
        ...

    def update(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#update

        **[slot] void QGraphicsEffect::update()**

        Schedules a redraw of the effect. Call this function whenever the effect
        needs to be redrawn. This function does not trigger a redraw of the
        source.

        **See also** **updateBoundingRect** ().
        """
        ...

    def setEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#enabled-prop

        **enabled : bool**

        This property holds whether the effect is enabled or not.

        If an effect is disabled, the source will be rendered with as normal,
        with no interference from the effect. If the effect is enabled, the
        source will be rendered with the effect applied.

        This property is enabled by default.

        Using this property, you can disable certain effects on slow platforms,
        in order to ensure that the user interface is responsive.

        **Access functions:**

        bool **isEnabled** () const
        void **setEnabled** (bool **enable** )

        **Notifier signal:**

        void ****enabledChanged** ** (bool **enabled** )

        **Member Function Documentation**
        """
        ...

    def isEnabled(self) -> bool:
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#boundingRect

        **QRectF QGraphicsEffect::boundingRect() const**

        Returns the effective bounding rectangle for this effect, i.e., the
        bounding rectangle of the source in device coordinates, adjusted by any
        margins applied by the effect itself.

        **See also** **boundingRectFor** () and **updateBoundingRect** ().
        """
        ...

    def boundingRectFor(self, sourceRect: QtCore.QRectF) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#boundingRectFor

        **[virtual] QRectF QGraphicsEffect::boundingRectFor(const QRectF & rect
        ) const**

        Returns the effective bounding rectangle for this effect, given the
        provided **rect** in the device coordinates. When writing you own custom
        effect, you must call **updateBoundingRect** () whenever any parameters
        are changed that may cause this this function to return a different
        value.

        **See also** **sourceBoundingRect** ().
        """
        ...

    @property
    def enabledChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicseffect.html#enabledChanged

        **[signal] void QGraphicsEffect::enabledChanged(bool enabled )**

        This signal is emitted whenever the effect is enabled or disabled. The
        **enabled** parameter holds the effects's new enabled state.

        **Note:** Notifier signal for property **enabled** .

        **See also** **isEnabled** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QXmlStreamAttributes(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamattributes.html

    **Detailed Description**

    Attributes are returned by a **QXmlStreamReader**  in **attributes** () when
    the reader reports a **start element** . The class can also be used with a
    **QXmlStreamWriter**  as an argument to **writeAttributes** ().

    The convenience function **value** () loops over the vector and returns an
    attribute value for a given namespaceUri and an attribute's name.

    New attributes can be added with **append** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#QXmlStreamAttributes

        **QXmlStreamAttributes::QXmlStreamAttributes()**

        A constructor for QXmlStreamAttributes.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QXmlStreamAttributes") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#QXmlStreamAttributes

        **QXmlStreamAttributes::QXmlStreamAttributes()**

        A constructor for QXmlStreamAttributes.
        """
        ...

    def __contains__(self, value: QXmlStreamAttribute) -> int:
        ...

    @typing.overload
    def __delitem__(self, i: int) -> None:
        ...

    @typing.overload
    def __delitem__(self, slice: slice) -> None:
        ...

    @typing.overload
    def __setitem__(self, i: int, value: QXmlStreamAttribute) -> None:
        ...

    @typing.overload
    def __setitem__(self, slice: slice, list: "QXmlStreamAttributes") -> None:
        ...

    @typing.overload
    def __getitem__(self, i: int) -> QXmlStreamAttribute:
        ...

    @typing.overload
    def __getitem__(self, slice: slice) -> "QXmlStreamAttributes":
        ...

    def size(self) -> int:
        ...

    def replace(self, i: int, value: QXmlStreamAttribute) -> None:
        ...

    @typing.overload
    def remove(self, i: int) -> None:
        ...

    @typing.overload
    def remove(self, i: int, count: int) -> None:
        ...

    def prepend(self, value: QXmlStreamAttribute) -> None:
        ...

    def lastIndexOf(self, value: QXmlStreamAttribute, from_: int = ...) -> int:
        ...

    def last(self) -> QXmlStreamAttribute:
        ...

    def isEmpty(self) -> bool:
        ...

    def insert(self, i: int, value: QXmlStreamAttribute) -> None:
        ...

    def indexOf(self, value: QXmlStreamAttribute, from_: int = ...) -> int:
        ...

    def first(self) -> QXmlStreamAttribute:
        ...

    def fill(self, value: QXmlStreamAttribute, size: int = ...) -> None:
        ...

    def data(self) -> PyQt6.sip.voidptr:
        ...

    def __len__(self) -> int:
        ...

    @typing.overload
    def count(self, value: QXmlStreamAttribute) -> int:
        ...

    @typing.overload
    def count(self) -> int:
        ...

    def contains(self, value: QXmlStreamAttribute) -> bool:
        ...

    def clear(self) -> None:
        ...

    def at(self, i: int) -> QXmlStreamAttribute:
        ...

    @typing.overload
    def hasAttribute(self, namespaceUri: str, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#hasAttribute

        **bool QXmlStreamAttributes::hasAttribute(const QString & qualifiedName
        ) const**

        Returns `true` if this **QXmlStreamAttributes**  has an attribute whose
        qualified name is **qualifiedName** ; otherwise returns `false`.

        Note that this is not namespace aware. For instance, if this
        **QXmlStreamAttributes**  contains an attribute whose lexical name is
        "xlink:href" this doesn't tell that an attribute named `href` in the
        XLink namespace is present, since the `xlink` prefix can be bound to any
        namespace. Use the overload that takes a namespace URI and a local name
        as parameter, for namespace aware code.
        """
        ...

    @typing.overload
    def hasAttribute(self, qualifiedName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#hasAttribute-1

        **bool QXmlStreamAttributes::hasAttribute(QLatin1String qualifiedName )
        const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def append(self, namespaceUri: str, name: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#append

        **void QXmlStreamAttributes::append(const QString & namespaceUri , const
        QString & name , const QString & value )**

        Appends a new attribute with **name** in the namespace described with
        **namespaceUri** , and value **value**. The **namespaceUri** can be
        empty.
        """
        ...

    @typing.overload
    def append(self, qualifiedName: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#append-1

        **void QXmlStreamAttributes::append(const QString & qualifiedName ,
        const QString & value )**

        This is an overloaded function.

        Appends a new attribute with qualified name **qualifiedName** and value
        **value**.
        """
        ...

    @typing.overload
    def append(self, value: QXmlStreamAttribute) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#append

        **void QXmlStreamAttributes::append(const QString & namespaceUri , const
        QString & name , const QString & value )**

        Appends a new attribute with **name** in the namespace described with
        **namespaceUri** , and value **value**. The **namespaceUri** can be
        empty.
        """
        ...

    @typing.overload
    def value(self, namespaceUri: str, name: str) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#value

        **QStringView QXmlStreamAttributes::value(const QString & namespaceUri ,
        const QString & name ) const**

        Returns the value of the attribute **name** in the namespace described
        with **namespaceUri** , or an empty string reference if the attribute is
        not defined. The **namespaceUri** can be empty.
        """
        ...

    @typing.overload
    def value(self, qualifiedName: str) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamattributes.html#value-1

        **QStringView QXmlStreamAttributes::value(const QString & namespaceUri ,
        QLatin1String name ) const**

        This is an overloaded function.

        Returns the value of the attribute **name** in the namespace described
        with **namespaceUri** , or an empty string reference if the attribute is
        not defined. The **namespaceUri** can be empty.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtSql import *
import enum


class QSql(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsql.html

    **Detailed Description**

    **See also** **Qt SQL** .
    """

    class NumericalPrecisionPolicy(enum.Enum):
        LowPrecisionInt32: QSql = ...
        LowPrecisionInt64: QSql = ...
        LowPrecisionDouble: QSql = ...
        HighPrecision: QSql = ...

    class TableType(enum.Enum):
        Tables: QSql = ...
        SystemTables: QSql = ...
        Views: QSql = ...
        AllTables: QSql = ...

    class ParamTypeFlag(enum.Flag):
        In: QSql = ...
        Out: QSql = ...
        InOut: QSql = ...
        Binary: QSql = ...

    class Location(enum.Enum):
        BeforeFirstRow: QSql = ...
        AfterLastRow: QSql = ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtPositioning import *


class QGeoPolygon(QGeoShape):
    """
    https://doc.qt.io/qt-6/qgeopolygon.html

    **Detailed Description**

    The polygon is defined by an ordered list of **QGeoCoordinate**  objects
    representing its perimeter.

    Each two adjacent elements in this list are intended to be connected
    together by the shortest line segment of constant bearing passing through
    both elements. This type of connection can cross the date line in the
    longitudinal direction, but never crosses the poles.

    This is relevant for the calculation of the bounding box returned by
    **QGeoShape::boundingGeoRectangle** () for this shape, which will have the
    latitude of the top left corner set to the maximum latitude in the path
    point set. Similarly, the latitude of the bottom right corner will be the
    minimum latitude in the path point set.

    This class is a **Q_GADGET** . It can be **directly used from C++ and QML**
    .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#QGeoPolygon

        **QGeoPolygon::QGeoPolygon()**

        Constructs a new, empty geo polygon.
        """
        ...

    @typing.overload
    def __init__(self, path: typing.Iterable[QGeoCoordinate]) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#QGeoPolygon-1

        **QGeoPolygon::QGeoPolygon(const QList<QGeoCoordinate> & path )**

        Constructs a new geo polygon from the coordinates specified in **path**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoPolygon") -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#QGeoPolygon-2

        **QGeoPolygon::QGeoPolygon(const QGeoPolygon & other )**

        Constructs a new geo polygon from the contents of **other**.
        """
        ...

    @typing.overload
    def __init__(self, other: QGeoShape) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#QGeoPolygon-3

        **QGeoPolygon::QGeoPolygon(const QGeoShape & other )**

        Constructs a new geo polygon from the contents of **other**.
        """
        ...

    def perimeter(self) -> typing.List[QGeoCoordinate]:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#perimeter

        **[since QtPositioning 5.12] const QList<QGeoCoordinate>
        &QGeoPolygon::perimeter() const**

        Returns all the elements of the polygon's perimeter.

        **Note:** Getter function for property perimeter.

        This function was introduced in QtPositioning 5.12.

        **See also** **setPerimeter** ().
        """
        ...

    def setPerimeter(self, path: typing.Iterable[QGeoCoordinate]) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#setPerimeter

        **[since QtPositioning 5.12] void QGeoPolygon::setPerimeter(const
        QList<QGeoCoordinate> & path )**

        Sets the perimeter of the polygon based on a list of coordinates
        **path**.

        **Note:** Setter function for property **perimeter** .

        This function was introduced in QtPositioning 5.12.

        **See also** **perimeter** ().
        """
        ...

    def holesCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#holesCount

        **[invokable, since 5.12] qsizetype QGeoPolygon::holesCount() const**

        Returns the number of holes.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.12.
        """
        ...

    def removeHole(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#removeHole

        **[invokable, since 5.12] void QGeoPolygon::removeHole(qsizetype index
        )**

        Removes element at position **index** from the list of holes.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.12.
        """
        ...

    def holePath(self, index: int) -> typing.List[QGeoCoordinate]:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#holePath

        **[since 5.12] const QList<QGeoCoordinate>
        QGeoPolygon::holePath(qsizetype index ) const**

        Returns a **QList** <**QGeoCoordinate** > which represents the hole at
        **index**.

        This function was introduced in Qt 5.12.
        """
        ...

    def hole(self, index: int) -> typing.List[typing.Any]:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#hole

        **[invokable, since 5.12] const QVariantList QGeoPolygon::hole(qsizetype
        index ) const**

        Returns a **QVariant**  containing a **QList** <**QGeoCoordinate** >
        which represents the hole at **index**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.12.
        """
        ...

    @typing.overload
    def addHole(self, holePath: typing.Iterable[QGeoCoordinate]) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#addHole

        **[invokable, since 5.12] void QGeoPolygon::addHole(const QVariant &
        holePath )**

        Sets the **holePath** for a hole inside the polygon. The hole is a
        **QVariant**  containing a **QList** <**QGeoCoordinate** >.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.12.
        """
        ...

    @typing.overload
    def addHole(self, holePath: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#addHole-1

        **[since 5.12] void QGeoPolygon::addHole(const QList<QGeoCoordinate> &
        holePath )**

        Overloaded method. Sets the **holePath** for a hole inside the polygon.
        The hole is a **QList** <**QGeoCoordinate** >.

        This function was introduced in Qt 5.12.
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#toString

        **[invokable] QString QGeoPolygon::toString() const**

        Returns the geo polygon properties as a string.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @typing.overload
    def removeCoordinate(self, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#removeCoordinate

        **[invokable] void QGeoPolygon::removeCoordinate(const QGeoCoordinate &
        coordinate )**

        Removes the last occurrence of **coordinate** from the polygon.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @typing.overload
    def removeCoordinate(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#removeCoordinate-1

        **[invokable] void QGeoPolygon::removeCoordinate(qsizetype index )**

        Removes element at position **index** from the polygon.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def containsCoordinate(self, coordinate: QGeoCoordinate) -> bool:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#containsCoordinate

        **[invokable] bool QGeoPolygon::containsCoordinate(const QGeoCoordinate
        & coordinate ) const**

        Returns true if the polygon's perimeter contains **coordinate** as one
        of the elements.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def coordinateAt(self, index: int) -> QGeoCoordinate:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#coordinateAt

        **[invokable] QGeoCoordinate QGeoPolygon::coordinateAt(qsizetype index )
        const**

        Returns the coordinate at **index** .

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def replaceCoordinate(self, index: int, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#replaceCoordinate

        **[invokable] void QGeoPolygon::replaceCoordinate(qsizetype index ,
        const QGeoCoordinate & coordinate )**

        Replaces the path element at the specified **index** with
        **coordinate**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def insertCoordinate(self, index: int, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#insertCoordinate

        **[invokable] void QGeoPolygon::insertCoordinate(qsizetype index , const
        QGeoCoordinate & coordinate )**

        Inserts **coordinate** at the specified **index**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def addCoordinate(self, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#addCoordinate

        **[invokable] void QGeoPolygon::addCoordinate(const QGeoCoordinate &
        coordinate )**

        Appends **coordinate** to the polygon.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#size

        **[invokable, since 5.10] qsizetype QGeoPolygon::size() const**

        Returns the number of elements in the polygon.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.10.
        """
        ...

    def length(self, indexFrom: int = ..., indexTo: int = ...) -> float:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#length

        **[invokable] double QGeoPolygon::length(qsizetype indexFrom = 0,
        qsizetype indexTo = -1) const**

        Returns the length of the polygon's perimeter, in meters, from the
        element **indexFrom** to the element **indexTo**. The length is intended
        to be the sum of the shortest distances for each pair of adjacent
        points.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def translated(
        self, degreesLatitude: float, degreesLongitude: float
    ) -> "QGeoPolygon":
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#translated

        **[invokable] QGeoPolygon QGeoPolygon::translated(double degreesLatitude
        , double degreesLongitude ) const**

        Returns a copy of this geo polygon translated by **degreesLatitude**
        northwards and **degreesLongitude** eastwards.

        Negative values of **degreesLatitude** and **degreesLongitude**
        correspond to southward and westward translation respectively.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **translate** ().
        """
        ...

    def translate(self, degreesLatitude: float, degreesLongitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeopolygon.html#translate

        **[invokable] void QGeoPolygon::translate(double degreesLatitude ,
        double degreesLongitude )**

        Translates this geo polygon by **degreesLatitude** northwards and
        **degreesLongitude** eastwards.

        Negative values of **degreesLatitude** and **degreesLongitude**
        correspond to southward and westward translation respectively.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QInputMethod(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qinputmethod.html

    **Detailed Description**

    QInputMethod is used by the text editors for integrating to the platform
    text input methods and more commonly by application views for querying
    various text input method-related information like virtual keyboard
    visibility and keyboard dimensions.

    Qt Quick also provides access to QInputMethod in QML through **Qt global
    object**  as `Qt.inputMethod` property.
    """

    class Action(enum.Enum):
        Click: QInputMethod = ...
        ContextMenu: QInputMethod = ...

    def inputItemClipRectangle(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#inputItemClipRectangle-prop

        **[read-only] inputItemClipRectangle : const QRectF**

        Input item's clipped rectangle in window coordinates.

        The clipped input rectangle is often used by various input methods to
        determine how much screen real estate is available for the input method
        (e.g. Virtual Keyboard).

        **Access functions:**

        QRectF **inputItemClipRectangle** () const

        **Notifier signal:**

        void **inputItemClipRectangleChanged** ()
        """
        ...

    def anchorRectangle(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#anchorRectangle-prop

        **[read-only] anchorRectangle : const QRectF**

        Input item's anchor rectangle in window coordinates.

        Anchor rectangle is often used by various text editing controls like
        text prediction popups for following the text selection.

        **Access functions:**

        QRectF **anchorRectangle** () const

        **Notifier signal:**

        void **anchorRectangleChanged** ()
        """
        ...

    def invokeAction(self, a: "QInputMethod.Action", cursorPosition: int) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#invokeAction

        **[slot] void QInputMethod::invokeAction(QInputMethod::Action a , int
        cursorPosition )**

        Called by the input item when the word currently being composed is
        tapped by the user, as indicated by the action **a** and the given
        **cursorPosition**. Input methods often use this information to offer
        more word suggestions to the user.
        """
        ...

    def commit(self) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#commit

        **[slot] void QInputMethod::commit()**

        Commits the word user is currently composing to the editor. The function
        is mostly needed by the input methods with text prediction features and
        by the methods where the script used for typing characters is different
        from the script that actually gets appended to the editor. Any kind of
        action that interrupts the text composing needs to flush the composing
        state by calling the commit() function, for example when the cursor is
        moved elsewhere.
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#reset

        **[slot] void QInputMethod::reset()**

        Resets the input method state. For example, a text editor normally calls
        this method before inserting a text to make widget ready to accept a
        text.

        Input method resets automatically when the focused editor changes.
        """
        ...

    def update(self, queries: QtCore.Qt.InputMethodQuery) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#update

        **[slot] void QInputMethod::update(Qt::InputMethodQueries queries )**

        Called by the input item to inform the platform input methods when there
        has been state changes in editor's input method query attributes. When
        calling the function **queries** parameter has to be used to tell what
        has changes, which input method can use to make queries for attributes
        it's interested with **QInputMethodQueryEvent** .

        In particular calling update whenever the cursor position changes is
        important as that often causes other query attributes like surrounding
        text and text selection to change as well. The attributes that often
        change together with cursor position have been grouped in
        **Qt::ImQueryInput**  value for convenience.
        """
        ...

    def hide(self) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#hide

        **[slot] void QInputMethod::hide()**

        Requests virtual keyboard to close.

        Normally applications should not need to call this function, keyboard
        should automatically close when the text editor loses focus, for example
        when the parent view is closed.
        """
        ...

    def show(self) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#show

        **[slot] void QInputMethod::show()**

        Requests virtual keyboard to open. If the platform doesn't provide
        virtual keyboard the visibility remains false.

        Normally applications should not need to call this function, keyboard
        should automatically open when the text editor gains focus.
        """
        ...

    @staticmethod
    def queryFocusObject(
        query: QtCore.Qt.InputMethodQuery, argument: typing.Any
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#queryFocusObject

        **[static] QVariant QInputMethod::queryFocusObject(Qt::InputMethodQuery
        query , const QVariant & argument )**

        Send **query** to the current focus object with parameters **argument**
        and return the result.
        """
        ...

    def setInputItemRectangle(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#setInputItemRectangle

        **[since 5.1] void QInputMethod::setInputItemRectangle(const QRectF &
        rect )**

        Sets the input item's geometry to be **rect** , in input item
        coordinates. This needs to be updated by the focused window like
        QQuickCanvas whenever item is moved inside the scene, or focus is
        changed.

        This function was introduced in Qt 5.1.

        **See also** **inputItemRectangle** ().
        """
        ...

    def inputItemRectangle(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#inputItemRectangle

        **[since 5.1] QRectF QInputMethod::inputItemRectangle() const**

        Returns the input item's geometry in input item coordinates.

        This function was introduced in Qt 5.1.

        **See also** **setInputItemRectangle** ().
        """
        ...

    def inputDirection(self) -> QtCore.Qt.LayoutDirection:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#inputDirection-prop

        **[read-only] inputDirection : const Qt::LayoutDirection**

        Current input direction.

        **Access functions:**

        Qt::LayoutDirection **inputDirection** () const

        **Notifier signal:**

        void **inputDirectionChanged** (Qt::LayoutDirection **newDirection** )
        """
        ...

    def locale(self) -> QtCore.QLocale:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#locale-prop

        **[read-only] locale : const QLocale**

        Current input locale.

        **Access functions:**

        QLocale **locale** () const

        **Notifier signal:**

        void **localeChanged** ()
        """
        ...

    def isAnimating(self) -> bool:
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#setVisible

        **void QInputMethod::setVisible(bool visible )**

        Controls the keyboard visibility. Equivalent to calling **show** () (if
        **visible** is `true`) or **hide** () (if **visible** is `false`).

        **See also** **isVisible** (), **show** (), and **hide** ().
        """
        ...

    def isVisible(self) -> bool:
        ...

    def keyboardRectangle(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#keyboardRectangle-prop

        **[read-only] keyboardRectangle : const QRectF**

        Virtual keyboard's geometry in window coordinates.

        This might be an empty rectangle if it is not possible to know the
        geometry of the keyboard. This is the case for a floating keyboard on
        android.

        **Access functions:**

        QRectF **keyboardRectangle** () const

        **Notifier signal:**

        void **keyboardRectangleChanged** ()
        """
        ...

    def cursorRectangle(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#cursorRectangle-prop

        **[read-only] cursorRectangle : const QRectF**

        Input item's cursor rectangle in window coordinates.

        Cursor rectangle is often used by various text editing controls like
        text prediction popups for following the text being typed.

        **Access functions:**

        QRectF **cursorRectangle** () const

        **Notifier signal:**

        void **cursorRectangleChanged** ()
        """
        ...

    def setInputItemTransform(self, transform: "QTransform") -> None:
        """
        https://doc.qt.io/qt-6/qinputmethod.html#setInputItemTransform

        **void QInputMethod::setInputItemTransform(const QTransform & transform
        )**

        Sets the transformation from input item coordinates to window
        coordinates to be **transform**. Item transform needs to be updated by
        the focused window like QQuickCanvas whenever item is moved inside the
        scene.

        **See also** **inputItemTransform** ().
        """
        ...

    def inputItemTransform(self) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qinputmethod.html#inputItemTransform

        **QTransform QInputMethod::inputItemTransform() const**

        Returns the transformation from input item coordinates to the window
        coordinates.

        **See also** **setInputItemTransform** ().
        """
        ...

    @property
    def anchorRectangleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def animatingChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def cursorRectangleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def inputDirectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def inputItemClipRectangleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def keyboardRectangleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def localeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def visibleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6.QtWidgets import *


class QWizardPage(QWidget):
    """
    https://doc.qt.io/qt-6/qwizardpage.html

    **Detailed Description**

    **QWizard**  represents a wizard. Each page is a QWizardPage. When you
    create your own wizards, you can use QWizardPage directly, or you can
    subclass it for more control.

    A page has the following attributes, which are rendered by **QWizard** : a
    **title** , a **subTitle** , and a **set of pixmaps** . See **Elements of a
    Wizard Page**  for details. Once a page is added to the wizard (using
    **QWizard::addPage** () or **QWizard::setPage** ()), **wizard** () returns a
    pointer to the associated **QWizard**  object.

    Page provides five virtual functions that can be reimplemented to provide
    custom behavior:

    * **initializePage** () is called to initialize the page's contents when the
    user clicks the wizard's **Next** button. If you want to derive the page's
    default from what the user entered on previous pages, this is the function
    to reimplement.
      * **cleanupPage** () is called to reset the page's
    contents when the user clicks the wizard's **Back** button.
      *
    **validatePage** () validates the page when the user clicks **Next** or
    **Finish**. It is often used to show an error message if the user has
    entered incomplete or invalid information.
      * **nextId** () returns the ID
    of the next page. It is useful when **creating non-linear wizards** , which
    allow different traversal paths based on the information provided by the
    user.
      * **isComplete** () is called to determine whether the **Next**
    and/or **Finish** button should be enabled or disabled. If you reimplement
    **isComplete** (), also make sure that **completeChanged** () is emitted
    whenever the complete state changes.

    Normally, the **Next** button and the **Finish** button of a wizard are
    mutually exclusive. If **isFinalPage** () returns `true`, **Finish** is
    available; otherwise, **Next** is available. By default, **isFinalPage** ()
    is true only when **nextId** () returns -1. If you want to show **Next** and
    **Final** simultaneously for a page (letting the user perform an "early
    finish"), call **setFinalPage** (true) on that page. For wizards that
    support early finishes, you might also want to set the
    **HaveNextButtonOnLastPage**  and **HaveFinishButtonOnEarlyPages**  options
    on the wizard.

    In many wizards, the contents of a page may affect the default values of the
    fields of a later page. To make it easy to communicate between pages,
    **QWizard**  supports a **"field" mechanism**  that allows you to register a
    field (e.g., a **QLineEdit** ) on a page and to access its value from any
    page. Fields are global to the entire wizard and make it easy for any single
    page to access information stored by another page, without having to put all
    the logic in **QWizard**  or having the pages know explicitly about each
    other. Fields are registered using **registerField** () and can be accessed
    at any time using **field** () and **setField** ().

    **See also** **QWizard** , **Class Wizard Example** , and **License Wizard
    Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#QWizardPage

        **QWizardPage::QWizardPage(QWidget * parent = nullptr)**

        Constructs a wizard page with the given **parent**.

        When the page is inserted into a wizard using **QWizard::addPage** () or
        **QWizard::setPage** (), the parent is automatically set to be the
        wizard.

        **See also** **wizard** ().
        """
        ...

    def wizard(self) -> QWizard:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#wizard

        **[protected] QWizard *QWizardPage::wizard() const**

        Returns the wizard associated with this page, or `nullptr` if this page
        hasn't been inserted into a **QWizard**  yet.

        **See also** **QWizard::addPage** () and **QWizard::setPage** ().
        """
        ...

    def registerField(
        self,
        name: str,
        widget: QWidget,
        property: typing.Optional[str] = ...,
        changedSignal: PYQT_SIGNAL = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#registerField

        **[protected] void QWizardPage::registerField(const QString & name ,
        QWidget * widget , const char * property = nullptr, const char *
        changedSignal = nullptr)**

        Creates a field called **name** associated with the given **property**
        of the given **widget**. From then on, that property becomes accessible
        using **field** () and **setField** ().

        Fields are global to the entire wizard and make it easy for any single
        page to access information stored by another page, without having to put
        all the logic in **QWizard**  or having the pages know explicitly about
        each other.

        If **name** ends with an asterisk (`*`), the field is a mandatory field.
        When a page has mandatory fields, the **Next** and/or **Finish** buttons
        are enabled only when all mandatory fields are filled. This requires a
        **changedSignal** to be specified, to tell **QWizard**  to recheck the
        value stored by the mandatory field.

        **QWizard**  knows the most common Qt widgets. For these (or their
        subclasses), you don't need to specify a **property** or a
        **changedSignal**. The table below lists these widgets:

        WidgetPropertyChange Notification Signal
        **QAbstractButton** bool
        **checked** **toggled** ()
        **QAbstractSlider** int **value**
        **valueChanged** ()
        **QComboBox** int **currentIndex**
        **currentIndexChanged** ()
        **QDateTimeEdit** **QDateTime**
        **dateTime** **dateTimeChanged** ()
        **QLineEdit** **QString**
        **text** **textChanged** ()
        **QListWidget** int **currentRow**
        **currentRowChanged** ()
        **QSpinBox** int **value** **valueChanged**
        ()

        You can use **QWizard::setDefaultProperty** () to add entries to this
        table or to override existing entries.

        To consider a field "filled", **QWizard**  simply checks that their
        current value doesn't equal their original value (the value they had
        before **initializePage** () was called). For **QLineEdit** , it also
        checks that **hasAcceptableInput** () returns true, to honor any
        validator or mask.

        **QWizard** 's mandatory field mechanism is provided for convenience. It
        can be bypassed by reimplementing **QWizardPage::isComplete** ().

        **See also** **field** (), **setField** (), and
        **QWizard::setDefaultProperty** ().
        """
        ...

    def field(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#field

        **[protected] QVariant QWizardPage::field(const QString & name ) const**

        Returns the value of the field called **name**.

        This function can be used to access fields on any page of the wizard. It
        is equivalent to calling **wizard** ()->**field( **name** )** .

        Example:

        void OutputFilesPage::initializePage()
            {
                **QString**
        className = field("className").toString();
        headerLineEdit->setText(className.toLower() + ".h");
        implementationLineEdit->setText(className.toLower() + ".cpp");
        outputDirLineEdit->setText(**QDir** ::toNativeSeparators(**QDir**
        ::tempPath()));
            }

        **See also** **QWizard::field** (), **setField** (), and
        **registerField** ().
        """
        ...

    def setField(self, name: str, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#setField

        **[protected] void QWizardPage::setField(const QString & name , const
        QVariant & value )**

        Sets the value of the field called **name** to **value**.

        This function can be used to set fields on any page of the wizard. It is
        equivalent to calling **wizard** ()->**setField( **name** , **value**
        )** .

        **See also** **QWizard::setField** (), **field** (), and
        **registerField** ().
        """
        ...

    def nextId(self) -> int:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#nextId

        **[virtual] int QWizardPage::nextId() const**

        This virtual function is called by **QWizard::nextId** () to find out
        which page to show when the user clicks the **Next** button.

        The return value is the ID of the next page, or -1 if no page follows.

        By default, this function returns the lowest ID greater than the ID of
        the current page, or -1 if there is no such ID.

        By reimplementing this function, you can specify a dynamic page order.
        For example:

        int IntroPage::nextId() const
            {
                if
        (evaluateRadioButton->isChecked()) {
                    return
        LicenseWizard::Page_Evaluate;
                } else {
                    return
        LicenseWizard::Page_Register;
                }
            }

        **See also** **QWizard::nextId** ().
        """
        ...

    def isComplete(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#isComplete

        **[virtual] bool QWizardPage::isComplete() const**

        This virtual function is called by **QWizard**  to determine whether the
        **Next** or **Finish** button should be enabled or disabled.

        The default implementation returns `true` if all **mandatory fields**
        are filled; otherwise, it returns `false`.

        If you reimplement this function, make sure to emit **completeChanged**
        (), from the rest of your implementation, whenever the value of
        isComplete() changes. This ensures that **QWizard**  updates the enabled
        or disabled state of its buttons. An example of the reimplementation is
        available **here** .

        **See also** **completeChanged** () and **isFinalPage** ().
        """
        ...

    def validatePage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#validatePage

        **[virtual] bool QWizardPage::validatePage()**

        This virtual function is called by **QWizard::validateCurrentPage** ()
        when the user clicks **Next** or **Finish** to perform some last-minute
        validation. If it returns `true`, the next page is shown (or the wizard
        finishes); otherwise, the current page stays up.

        The default implementation returns `true`.

        When possible, it is usually better style to disable the **Next** or
        **Finish** button (by specifying **mandatory fields**  or reimplementing
        **isComplete** ()) than to reimplement validatePage().

        **See also** **QWizard::validateCurrentPage** () and **isComplete** ().
        """
        ...

    def cleanupPage(self) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#cleanupPage

        **[virtual] void QWizardPage::cleanupPage()**

        This virtual function is called by **QWizard::cleanupPage** () when the
        user leaves the page by clicking **Back** (unless the
        **QWizard::IndependentPages**  option is set).

        The default implementation resets the page's fields to their original
        values (the values they had before **initializePage** () was called).

        **See also** **QWizard::cleanupPage** (), **initializePage** (), and
        **QWizard::IndependentPages** .
        """
        ...

    def initializePage(self) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#initializePage

        **[virtual] void QWizardPage::initializePage()**

        This virtual function is called by **QWizard::initializePage** () to
        prepare the page just before it is shown either as a result of
        **QWizard::restart** () being called, or as a result of the user
        clicking **Next**. (However, if the **QWizard::IndependentPages**
        option is set, this function is only called the first time the page is
        shown.)

        By reimplementing this function, you can ensure that the page's fields
        are properly initialized based on fields from previous pages. For
        example:

        void OutputFilesPage::initializePage()
            {
                **QString**
        className = field("className").toString();
        headerLineEdit->setText(className.toLower() + ".h");
        implementationLineEdit->setText(className.toLower() + ".cpp");
        outputDirLineEdit->setText(**QDir** ::toNativeSeparators(**QDir**
        ::tempPath()));
            }

        The default implementation does nothing.

        **See also** **QWizard::initializePage** (), **cleanupPage** (), and
        **QWizard::IndependentPages** .
        """
        ...

    def buttonText(self, which: QWizard.WizardButton) -> str:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#buttonText

        **QString QWizardPage::buttonText(QWizard::WizardButton which ) const**

        Returns the text on button **which** on this page.

        If a text has ben set using **setButtonText** (), this text is returned.
        Otherwise, if a text has been set using **QWizard::setButtonText** (),
        this text is returned.

        By default, the text on buttons depends on the **QWizard::wizardStyle**
        . For example, on macOS, the **Next** button is called **Continue**.

        **See also** **setButtonText** (), **QWizard::buttonText** (), and
        **QWizard::setButtonText** ().
        """
        ...

    def setButtonText(self, which: QWizard.WizardButton, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#setButtonText

        **void QWizardPage::setButtonText(QWizard::WizardButton which , const
        QString & text )**

        Sets the text on button **which** to be **text** on this page.

        By default, the text on buttons depends on the **QWizard::wizardStyle**
        , but may be redefined for the wizard as a whole using
        **QWizard::setButtonText** ().

        **See also** **buttonText** (), **QWizard::setButtonText** (), and
        **QWizard::buttonText** ().
        """
        ...

    def isCommitPage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#isCommitPage

        **bool QWizardPage::isCommitPage() const**

        Returns `true` if this page is a commit page; otherwise returns `false`.

        **See also** **setCommitPage** ().
        """
        ...

    def setCommitPage(self, commitPage: bool) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#setCommitPage

        **void QWizardPage::setCommitPage(bool commitPage )**

        Sets this page to be a commit page if **commitPage** is true; otherwise,
        sets it to be a normal page.

        A commit page is a page that represents an action which cannot be undone
        by clicking **Back** or **Cancel**.

        A **Commit** button replaces the **Next** button on a commit page.
        Clicking this button simply calls **QWizard::next** () just like
        clicking **Next** does.

        A page entered directly from a commit page has its **Back** button
        disabled.

        **See also** **isCommitPage** ().
        """
        ...

    def isFinalPage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#isFinalPage

        **bool QWizardPage::isFinalPage() const**

        This function is called by **QWizard**  to determine whether the
        **Finish** button should be shown for this page or not.

        By default, it returns `true` if there is no next page (i.e., **nextId**
        () returns -1); otherwise, it returns `false`.

        By explicitly calling **setFinalPage** (true), you can let the user
        perform an "early finish".

        **See also** **isComplete** () and
        **QWizard::HaveFinishButtonOnEarlyPages** .
        """
        ...

    def setFinalPage(self, finalPage: bool) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#setFinalPage

        **void QWizardPage::setFinalPage(bool finalPage )**

        Explicitly sets this page to be final if **finalPage** is true.

        After calling setFinalPage(true), **isFinalPage** () returns `true` and
        the **Finish** button is visible (and enabled if **isComplete** ()
        returns true).

        After calling setFinalPage(false), **isFinalPage** () returns `true` if
        **nextId** () returns -1; otherwise, it returns `false`.

        **See also** **isFinalPage** (), **isComplete** (), and
        **QWizard::HaveFinishButtonOnEarlyPages** .
        """
        ...

    def pixmap(self, which: QWizard.WizardPixmap) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#pixmap

        **QPixmap QWizardPage::pixmap(QWizard::WizardPixmap which ) const**

        Returns the pixmap set for role **which**.

        Pixmaps can also be set for the entire wizard using
        **QWizard::setPixmap** (), in which case they apply for all pages that
        don't specify a pixmap.

        **See also** **setPixmap** (), **QWizard::pixmap** (), and **Elements of
        a Wizard Page** .
        """
        ...

    def setPixmap(self, which: QWizard.WizardPixmap, pixmap: QtGui.QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#setPixmap

        **void QWizardPage::setPixmap(QWizard::WizardPixmap which , const
        QPixmap & pixmap )**

        Sets the pixmap for role **which** to **pixmap**.

        The pixmaps are used by **QWizard**  when displaying a page. Which
        pixmaps are actually used depend on the **wizard style** .

        Pixmaps can also be set for the entire wizard using
        **QWizard::setPixmap** (), in which case they apply for all pages that
        don't specify a pixmap.

        **See also** **pixmap** (), **QWizard::setPixmap** (), and **Elements of
        a Wizard Page** .
        """
        ...

    def subTitle(self) -> str:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#subTitle-prop

        **subTitle : QString**

        This property holds the subtitle of the page

        The subtitle is shown by the **QWizard** , between the title and the
        actual page. Subtitles are optional. In **ClassicStyle**  and
        **ModernStyle** , using subtitles is necessary to make the header
        appear. In **MacStyle** , the subtitle is shown as a text label just
        above the actual page.

        The subtitle may be plain text or HTML, depending on the value of the
        **QWizard::subTitleFormat**  property.

        By default, this property contains an empty string.

        **Access functions:**

        QString **subTitle** () const
        void **setSubTitle** (const QString &
        **subTitle** )

        **See also** **title** , **QWizard::IgnoreSubTitles** , and **Elements
        of a Wizard Page** .
        """
        ...

    def setSubTitle(self, subTitle: str) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#subTitle-prop

        **subTitle : QString**

        This property holds the subtitle of the page

        The subtitle is shown by the **QWizard** , between the title and the
        actual page. Subtitles are optional. In **ClassicStyle**  and
        **ModernStyle** , using subtitles is necessary to make the header
        appear. In **MacStyle** , the subtitle is shown as a text label just
        above the actual page.

        The subtitle may be plain text or HTML, depending on the value of the
        **QWizard::subTitleFormat**  property.

        By default, this property contains an empty string.

        **Access functions:**

        QString **subTitle** () const
        void **setSubTitle** (const QString &
        **subTitle** )

        **See also** **title** , **QWizard::IgnoreSubTitles** , and **Elements
        of a Wizard Page** .
        """
        ...

    def title(self) -> str:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#title-prop

        **title : QString**

        This property holds the title of the page

        The title is shown by the **QWizard** , above the actual page. All pages
        should have a title.

        The title may be plain text or HTML, depending on the value of the
        **QWizard::titleFormat**  property.

        By default, this property contains an empty string.

        **Access functions:**

        QString **title** () const
        void **setTitle** (const QString &
        **title** )

        **See also** **subTitle**  and **Elements of a Wizard Page** .

        **Member Function Documentation**
        """
        ...

    def setTitle(self, title: str) -> None:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#title-prop

        **title : QString**

        This property holds the title of the page

        The title is shown by the **QWizard** , above the actual page. All pages
        should have a title.

        The title may be plain text or HTML, depending on the value of the
        **QWizard::titleFormat**  property.

        By default, this property contains an empty string.

        **Access functions:**

        QString **title** () const
        void **setTitle** (const QString &
        **title** )

        **See also** **subTitle**  and **Elements of a Wizard Page** .

        **Member Function Documentation**
        """
        ...

    @property
    def completeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwizardpage.html#completeChanged

        **[signal] void QWizardPage::completeChanged()**

        This signal is emitted whenever the complete state of the page (i.e.,
        the value of **isComplete** ()) changes.

        If you reimplement **isComplete** (), make sure to emit
        completeChanged() whenever the value of **isComplete** () changes, to
        ensure that **QWizard**  updates the enabled or disabled state of its
        buttons.

        **See also** **isComplete** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QLayoutItem(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qlayoutitem.html

    **Detailed Description**

    This is used by custom layouts.

    Pure virtual functions are provided to return information about the layout,
    including, **sizeHint** (), **minimumSize** (), **maximumSize** () and
    expanding().

    The layout's geometry can be set and retrieved with **setGeometry** () and
    **geometry** (), and its alignment with **setAlignment** () and
    **alignment** ().

    **isEmpty** () returns whether the layout item is empty. If the concrete
    item is a **QWidget** , it can be retrieved using **widget** (). Similarly
    for **layout** () and **spacerItem** ().

    Some layouts have width and height interdependencies. These can be expressed
    using **hasHeightForWidth** (), **heightForWidth** (), and
    **minimumHeightForWidth** (). For more explanation see the **Qt Quarterly**
    article **Trading Height for Width** .

    **See also** **QLayout** .
    """

    @typing.overload
    def __init__(self, alignment: QtCore.Qt.AlignmentFlag = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#QLayoutItem

        **QLayoutItem::QLayoutItem(Qt::Alignment alignment = Qt::Alignment())**

        Constructs a layout item with an **alignment**. Not all subclasses
        support alignment.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QLayoutItem") -> None:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#QLayoutItem

        **QLayoutItem::QLayoutItem(Qt::Alignment alignment = Qt::Alignment())**

        Constructs a layout item with an **alignment**. Not all subclasses
        support alignment.
        """
        ...

    def controlTypes(self) -> "QSizePolicy.ControlType":
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#controlTypes

        **[virtual] QSizePolicy::ControlTypes QLayoutItem::controlTypes()
        const**

        Returns the control type(s) for the layout item. For a **QWidgetItem** ,
        the control type comes from the widget's size policy; for a
        **QLayoutItem** , the control types is derived from the layout's
        contents.

        **See also** **QSizePolicy::controlType** ().
        """
        ...

    def setAlignment(self, a: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#setAlignment

        **void QLayoutItem::setAlignment(Qt::Alignment alignment )**

        Sets the alignment of this item to **alignment**.

        **Note:** Item alignment is only supported by **QLayoutItem**
        subclasses where it would have a visual effect. Except for
        **QSpacerItem** , which provides blank space for layouts, all public Qt
        classes that inherit **QLayoutItem**  support item alignment.

        **See also** **alignment** ().
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#alignment

        **Qt::Alignment QLayoutItem::alignment() const**

        Returns the alignment of this item.

        **See also** **setAlignment** ().
        """
        ...

    def spacerItem(self) -> "QSpacerItem":
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#spacerItem

        **[virtual] QSpacerItem *QLayoutItem::spacerItem()**

        If this item is a **QSpacerItem** , it is returned as a **QSpacerItem**
        ; otherwise `nullptr` is returned. This function provides type-safe
        casting.

        **See also** **layout** () and **widget** ().
        """
        ...

    def layout(self) -> "QLayout":
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#layout

        **[virtual] QLayout *QLayoutItem::layout()**

        If this item is a **QLayout** , it is returned as a **QLayout** ;
        otherwise `nullptr` is returned. This function provides type-safe
        casting.

        **See also** **spacerItem** () and **widget** ().
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#widget

        **[virtual] QWidget *QLayoutItem::widget() const**

        If this item manages a **QWidget** , returns that widget. Otherwise,
        `nullptr` is returned.

        **Note:** While the functions **layout** () and **spacerItem** ()
        perform casts, this function returns another object: **QLayout**  and
        **QSpacerItem**  inherit **QLayoutItem** , while **QWidget**  does not.

        **See also** **layout** () and **spacerItem** ().
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#invalidate

        **[virtual] void QLayoutItem::invalidate()**

        Invalidates any cached information in this layout item.
        """
        ...

    def minimumHeightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#minimumHeightForWidth

        **[virtual] int QLayoutItem::minimumHeightForWidth(int w ) const**

        Returns the minimum height this widget needs for the given width, **w**.
        The default implementation simply returns **heightForWidth** ( **w** ).
        """
        ...

    def heightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#heightForWidth

        **[virtual] int QLayoutItem::heightForWidth(int) const**

        Returns the preferred height for this layout item, given the width,
        which is not used in this default implementation.

        The default implementation returns -1, indicating that the preferred
        height is independent of the width of the item. Using the function
        **hasHeightForWidth** () will typically be much faster than calling this
        function and testing for -1.

        Reimplement this function in layout managers that support height for
        width. A typical implementation will look like this:

        int MyLayout::heightForWidth(int w) const
            {
                if (cache_dirty
        || cached_width != w) {
                    MyLayout *that = const_cast<MyLayout
        \\*>(this);
                    int h = calculateHeightForWidth(w);
        that->cached_hfw = h;
                    return h;
                }
                return
        cached_hfw;
            }

        Caching is strongly recommended; without it layout will take exponential
        time.

        **See also** **hasHeightForWidth** ().
        """
        ...

    def hasHeightForWidth(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#hasHeightForWidth

        **[virtual] bool QLayoutItem::hasHeightForWidth() const**

        Returns `true` if this layout's preferred height depends on its width;
        otherwise returns `false`. The default implementation returns false.

        Reimplement this function in layout managers that support height for
        width.

        **See also** **heightForWidth** () and **QWidget::heightForWidth** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#isEmpty

        **[pure virtual] bool QLayoutItem::isEmpty() const**

        Implemented in subclasses to return whether this item is empty, i.e.
        whether it contains any widgets.
        """
        ...

    def geometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#geometry

        **[pure virtual] QRect QLayoutItem::geometry() const**

        Returns the rectangle covered by this layout item.

        **See also** **setGeometry** ().
        """
        ...

    def setGeometry(self, a0: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#setGeometry

        **[pure virtual] void QLayoutItem::setGeometry(const QRect & r )**

        Implemented in subclasses to set this item's geometry to **r**.

        **See also** **geometry** ().
        """
        ...

    def expandingDirections(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#expandingDirections

        **[pure virtual] Qt::Orientations QLayoutItem::expandingDirections()
        const**

        Returns whether this layout item can make use of more space than
        **sizeHint** (). A value of **Qt::Vertical**  or **Qt::Horizontal**
        means that it wants to grow in only one dimension, whereas
        **Qt::Vertical**  | **Qt::Horizontal**  means that it wants to grow in
        both dimensions.
        """
        ...

    def maximumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#maximumSize

        **[pure virtual] QSize QLayoutItem::maximumSize() const**

        Implemented in subclasses to return the maximum size of this item.
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#minimumSize

        **[pure virtual] QSize QLayoutItem::minimumSize() const**

        Implemented in subclasses to return the minimum size of this item.
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlayoutitem.html#sizeHint

        **[pure virtual] QSize QLayoutItem::sizeHint() const**

        Implemented in subclasses to return the preferred size of this item.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsDropShadowEffect(QGraphicsEffect):
    """
    https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html

    **Detailed Description**

    A drop shadow effect renders the source with a drop shadow. The color of the
    drop shadow can be modified using the **setColor** () function. The drop
    shadow offset can be modified using the **setOffset** () function and the
    blur radius of the drop shadow can be changed with the **setBlurRadius** ()
    function.

    By default, the drop shadow is a semi-transparent dark gray (**QColor** (63,
    63, 63, 180)) shadow, blurred with a radius of 1 at an offset of 8 pixels
    towards the lower right. The drop shadow offset is specified in device
    coordinates.

    ![](images/graphicseffect-drop-shadow.png)

    **See also** **QGraphicsBlurEffect** , **QGraphicsColorizeEffect** , and
    **QGraphicsOpacityEffect** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#QGraphicsDropShado
        wEffect

        **QGraphicsDropShadowEffect::QGraphicsDropShadowEffect(QObject * parent
        = nullptr)**

        Constructs a new QGraphicsDropShadowEffect instance. The **parent**
        parameter is passed to **QGraphicsEffect** 's constructor.
        """
        ...

    def draw(self, painter: QtGui.QPainter) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#draw

        **[override virtual protected] void
        QGraphicsDropShadowEffect::draw(QPainter * painter )**

        Reimplements: **QGraphicsEffect::draw** (QPainter *painter).
        """
        ...

    def setColor(
        self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#color-prop

        **color : QColor**

        This property holds the color of the drop shadow.

        By default, the drop color is a semi-transparent dark gray (**QColor**
        (63, 63, 63, 180)).

        **Access functions:**

        QColor **color** () const
        void **setColor** (const QColor & **color**
        )

        **Notifier signal:**

        void ****colorChanged** ** (const QColor & **color** )

        **See also** **offset** () and **blurRadius** ().
        """
        ...

    def setBlurRadius(self, blurRadius: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#blurRadius-prop

        **blurRadius : qreal**

        This property holds the blur radius in pixels of the drop shadow.

        Using a smaller radius results in a sharper shadow, whereas using a
        bigger radius results in a more blurred shadow.

        By default, the blur radius is 1 pixel.

        **Access functions:**

        qreal **blurRadius** () const
        void **setBlurRadius** (qreal
        **blurRadius** )

        **Notifier signal:**

        void ****blurRadiusChanged** ** (qreal **blurRadius** )

        **See also** **color** () and **offset** ().
        """
        ...

    def setYOffset(self, dy: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#yOffset-prop

        **yOffset : qreal**

        This property holds the vertical shadow offset in pixels.

        By default, the vertical shadow offset is 8 pixels.

        **Access functions:**

        qreal **yOffset** () const
        void **setYOffset** (qreal **dy** )

        **Notifier signal:**

        void ****offsetChanged** ** (const QPointF & **offset** )

        **See also** **xOffset** () and **offset** ().

        **Member Function Documentation**
        """
        ...

    def setXOffset(self, dx: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#xOffset-prop

        **xOffset : qreal**

        This property holds the horizontal shadow offset in pixels.

        By default, the horizontal shadow offset is 8 pixels.

        **Access functions:**

        qreal **xOffset** () const
        void **setXOffset** (qreal **dx** )

        **Notifier signal:**

        void ****offsetChanged** ** (const QPointF & **offset** )

        **See also** **yOffset** () and **offset** ().
        """
        ...

    @typing.overload
    def setOffset(self, ofs: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#offset-prop

        **offset : QPointF**

        This property holds the shadow offset in pixels.

        By default, the offset is 8 pixels towards the lower right.

        The offset is given in device coordinates, which means it is unaffected
        by scale.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **ofs** )
        void **setOffset** (qreal **dx** , qreal **dy** )
        void
        **setOffset** (qreal **d** )

        **Notifier signal:**

        void ****offsetChanged** ** (const QPointF & **offset** )

        **See also** **xOffset** (), **yOffset** (), **blurRadius** (), and
        **color** ().
        """
        ...

    @typing.overload
    def setOffset(self, dx: float, dy: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#offset-prop

        **offset : QPointF**

        This property holds the shadow offset in pixels.

        By default, the offset is 8 pixels towards the lower right.

        The offset is given in device coordinates, which means it is unaffected
        by scale.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **ofs** )
        void **setOffset** (qreal **dx** , qreal **dy** )
        void
        **setOffset** (qreal **d** )

        **Notifier signal:**

        void ****offsetChanged** ** (const QPointF & **offset** )

        **See also** **xOffset** (), **yOffset** (), **blurRadius** (), and
        **color** ().
        """
        ...

    @typing.overload
    def setOffset(self, d: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#offset-prop

        **offset : QPointF**

        This property holds the shadow offset in pixels.

        By default, the offset is 8 pixels towards the lower right.

        The offset is given in device coordinates, which means it is unaffected
        by scale.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **ofs** )
        void **setOffset** (qreal **dx** , qreal **dy** )
        void
        **setOffset** (qreal **d** )

        **Notifier signal:**

        void ****offsetChanged** ** (const QPointF & **offset** )

        **See also** **xOffset** (), **yOffset** (), **blurRadius** (), and
        **color** ().
        """
        ...

    def color(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#color-prop

        **color : QColor**

        This property holds the color of the drop shadow.

        By default, the drop color is a semi-transparent dark gray (**QColor**
        (63, 63, 63, 180)).

        **Access functions:**

        QColor **color** () const
        void **setColor** (const QColor & **color**
        )

        **Notifier signal:**

        void ****colorChanged** ** (const QColor & **color** )

        **See also** **offset** () and **blurRadius** ().
        """
        ...

    def blurRadius(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#blurRadius-prop

        **blurRadius : qreal**

        This property holds the blur radius in pixels of the drop shadow.

        Using a smaller radius results in a sharper shadow, whereas using a
        bigger radius results in a more blurred shadow.

        By default, the blur radius is 1 pixel.

        **Access functions:**

        qreal **blurRadius** () const
        void **setBlurRadius** (qreal
        **blurRadius** )

        **Notifier signal:**

        void ****blurRadiusChanged** ** (qreal **blurRadius** )

        **See also** **color** () and **offset** ().
        """
        ...

    def yOffset(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#yOffset-prop

        **yOffset : qreal**

        This property holds the vertical shadow offset in pixels.

        By default, the vertical shadow offset is 8 pixels.

        **Access functions:**

        qreal **yOffset** () const
        void **setYOffset** (qreal **dy** )

        **Notifier signal:**

        void ****offsetChanged** ** (const QPointF & **offset** )

        **See also** **xOffset** () and **offset** ().

        **Member Function Documentation**
        """
        ...

    def xOffset(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#xOffset-prop

        **xOffset : qreal**

        This property holds the horizontal shadow offset in pixels.

        By default, the horizontal shadow offset is 8 pixels.

        **Access functions:**

        qreal **xOffset** () const
        void **setXOffset** (qreal **dx** )

        **Notifier signal:**

        void ****offsetChanged** ** (const QPointF & **offset** )

        **See also** **yOffset** () and **offset** ().
        """
        ...

    def offset(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#offset-prop

        **offset : QPointF**

        This property holds the shadow offset in pixels.

        By default, the offset is 8 pixels towards the lower right.

        The offset is given in device coordinates, which means it is unaffected
        by scale.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **ofs** )
        void **setOffset** (qreal **dx** , qreal **dy** )
        void
        **setOffset** (qreal **d** )

        **Notifier signal:**

        void ****offsetChanged** ** (const QPointF & **offset** )

        **See also** **xOffset** (), **yOffset** (), **blurRadius** (), and
        **color** ().
        """
        ...

    def boundingRectFor(self, rect: QtCore.QRectF) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#boundingRectFor

        **[override virtual] QRectF
        QGraphicsDropShadowEffect::boundingRectFor(const QRectF & rect ) const**

        Reimplements: **QGraphicsEffect::boundingRectFor(const QRectF &rect)
        const** .
        """
        ...

    @property
    def blurRadiusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#blurRadiusChanged

        **[signal] void QGraphicsDropShadowEffect::blurRadiusChanged(qreal
        blurRadius )**

        This signal is emitted whenever the effect's blur radius changes. The
        **blurRadius** parameter holds the effect's new blur radius.

        **Note:** Notifier signal for property **blurRadius** .
        """
        ...

    @property
    def colorChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#colorChanged

        **[signal] void QGraphicsDropShadowEffect::colorChanged(const QColor &
        color )**

        This signal is emitted whenever the effect's color changes. The
        **color** parameter holds the effect's new color.

        **Note:** Notifier signal for property **color** .
        """
        ...

    @property
    def offsetChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsdropshadoweffect.html#offsetChanged

        **[signal] void QGraphicsDropShadowEffect::offsetChanged(const QPointF &
        offset )**

        This signal is emitted whenever the effect's shadow offset changes. The
        **offset** parameter holds the effect's new shadow offset.

        **Note:** Notifier signal for property **offset** . Notifier signal for
        property **xOffset** . Notifier signal for property **yOffset** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWebChannel import *


class QWebChannel(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qwebchannel.html

    **Detailed Description**

    The QWebChannel fills the gap between C++ applications and HTML/JavaScript
    applications. By publishing a **QObject**  derived object to a QWebChannel
    and using the **qwebchannel.js**  on the HTML side, one can transparently
    access properties and public slots and methods of the **QObject** . No
    manual message passing and serialization of data is required, property
    updates and signal emission on the C++ side get automatically transmitted to
    the potentially remotely running HTML clients. On the client side, a
    JavaScript object will be created for any published C++ **QObject** . It
    mirrors the C++ object's API and thus is intuitively useable.

    The C++ QWebChannel API makes it possible to talk to any HTML client, which
    could run on a local or even remote machine. The only limitation is that the
    HTML client supports the JavaScript features used by `qwebchannel.js`. As
    such, one can interact with basically any modern HTML browser or standalone
    JavaScript runtime, such as node.js.

    There also exists a declarative **WebChannel API** .

    **See also** **Qt WebChannel Standalone Example**  and **JavaScript API** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#QWebChannel-1

        **QWebChannel::QWebChannel(QObject * parent = nullptr)**

        Constructs the QWebChannel object with the given **parent**.

        Note that a QWebChannel is only fully operational once you connect it to
        a **QWebChannelAbstractTransport** . The HTML clients also need to be
        setup appropriately using [`qwebchannel.js`** .
        """
        ...

    def disconnectFrom(self, transport: "QWebChannelAbstractTransport") -> None:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#disconnectFrom

        **[slot] void QWebChannel::disconnectFrom(QWebChannelAbstractTransport *
        transport )**

        Disconnects the **QWebChannel**  from the **transport** object.

        **See also** **QWebChannel::connectTo** ().
        """
        ...

    def connectTo(self, transport: "QWebChannelAbstractTransport") -> None:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#connectTo

        **[slot] void QWebChannel::connectTo(QWebChannelAbstractTransport *
        transport )**

        Connects the **QWebChannel**  to the given **transport** object.

        The transport object then handles the communication between the C++
        application and a remote HTML client.

        **See also** **QWebChannelAbstractTransport**  and
        **QWebChannel::disconnectFrom** ().
        """
        ...

    def setPropertyUpdateInterval(self, ms: int) -> None:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#propertyUpdateInterval-prop

        **[bindable] propertyUpdateInterval : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the property update interval.

        This interval can be changed to a different interval in milliseconds by
        setting it to a positive value. Property updates are batched and sent
        out after the interval expires. If set to zero, the updates occurring
        within a single event loop run are batched and sent out on the next run.
        If negative, updates will be sent immediately. Default value is 50
        milliseconds.

        **Member Function Documentation**
        """
        ...

    def propertyUpdateInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#propertyUpdateInterval-prop

        **[bindable] propertyUpdateInterval : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the property update interval.

        This interval can be changed to a different interval in milliseconds by
        setting it to a positive value. Property updates are batched and sent
        out after the interval expires. If set to zero, the updates occurring
        within a single event loop run are batched and sent out on the next run.
        If negative, updates will be sent immediately. Default value is 50
        milliseconds.

        **Member Function Documentation**
        """
        ...

    def setBlockUpdates(self, block: bool) -> None:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#blockUpdates-prop

        **[bindable] blockUpdates : bool**

        **Note:** This property supports **QProperty**  bindings.

        When set to true, updates are blocked and remote clients will not be
        notified about property changes.

        The changes are recorded and sent to the clients once updates become
        unblocked again by setting this property to false. By default, updates
        are not blocked.
        """
        ...

    def blockUpdates(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#blockUpdates-prop

        **[bindable] blockUpdates : bool**

        **Note:** This property supports **QProperty**  bindings.

        When set to true, updates are blocked and remote clients will not be
        notified about property changes.

        The changes are recorded and sent to the clients once updates become
        unblocked again by setting this property to false. By default, updates
        are not blocked.
        """
        ...

    def deregisterObject(self, object: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#deregisterObject

        **[invokable] void QWebChannel::deregisterObject(QObject * object )**

        Deregisters the given **object** from the **QWebChannel** .

        Remote clients will receive a `destroyed` signal for the given object.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **QWebChannel::registerObjects** (),
        **QWebChannel::registerObject** (), and
        **QWebChannel::registeredObjects** ().
        """
        ...

    def registerObject(self, id: str, object: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#registerObject

        **[invokable] void QWebChannel::registerObject(const QString & id ,
        QObject * object )**

        Registers a single object to the **QWebChannel** .

        The properties, signals and public methods of the **object** are
        published to the remote clients. There, an object with the identifier
        **id** is then constructed.

        **Note:** A property that is `BINDABLE` but does not have a `NOTIFY`
        signal will have working property updates on the client side, but no
        mechanism to register a callback for the change notifications.

        **Note:** A current limitation is that objects must be registered before
        any client is initialized.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **QWebChannel::registerObjects** (),
        **QWebChannel::deregisterObject** (), and
        **QWebChannel::registeredObjects** ().
        """
        ...

    def registeredObjects(self) -> typing.Dict[str, QtCore.QObject]:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#registeredObjects

        **QHash<QString, QObject *> QWebChannel::registeredObjects() const**

        Returns the map of registered objects that are published to remote
        clients.

        **See also** **QWebChannel::registerObjects** (),
        **QWebChannel::registerObject** (), and
        **QWebChannel::deregisterObject** ().
        """
        ...

    def registerObjects(self, objects: typing.Dict[str, QtCore.QObject]) -> None:
        """
        https://doc.qt.io/qt-6/qwebchannel.html#registerObjects

        **void QWebChannel::registerObjects(const QHash<QString, QObject *> &
        objects )**

        Registers a group of objects to the **QWebChannel** .

        The properties, signals and public invokable methods of the objects are
        published to the remote clients. There, an object with the identifier
        used as key in the **objects** map is then constructed.

        **Note:** A current limitation is that objects must be registered before
        any client is initialized.

        **See also** **QWebChannel::registerObject** (),
        **QWebChannel::deregisterObject** (), and
        **QWebChannel::registeredObjects** ().
        """
        ...

    @property
    def blockUpdatesChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...
